      SUBROUTINE XSQY_GLYALD(nw,wl,wc,nz,tlev,airden,j,sq,jlabel,pn)
!---------------------------------------------------------------------------!
!  PURPOSE:                                                                 !
!  Provide the product (cross section) x (quantum yield) for CH2(OH)CHO     !
!  (glycolaldehye, hydroxy acetaldehyde) photolysis:                        !
!           GLYALD(CH2(OH)CHO) + hv -> Products                             !
!                                                                           !
!  Cross section from                                                       !
!              The Atmospheric Chemistry of Glycolaldehyde,                 !
!              C. Bacher, G. S. Tyndall  and J. J. Orlando,                 !
!              J. Atmos. Chem., 39 (2001) 171-189.                          !
!                                                                           !
!  Quantum yield about 50%                                                  !
!---------------------------------------------------------------------------!
!  PARAMETERS:                                                              !
!  NW     - INTEGER, number of specified intervals + 1 in working        (I)!
!           wavelength grid                                                 !
!  WL     - REAL, vector of lower limits of wavelength intervals in      (I)!
!           working wavelength grid                                         !
!  WC     - REAL, vector of center points of wavelength intervals in     (I)!
!           working wavelength grid                                         !
!  NZ     - INTEGER, number of altitude levels in working altitude grid  (I)!
!  TLEV   - REAL, temperature (K) at each specified altitude level       (I)!
!  AIRDEN - REAL, air density (molec/cc) at each altitude level          (I)!
!  J      - INTEGER, counter for number of weighting functions defined  (IO)!
!  SQ     - REAL, cross section x quantum yield (cm^2) for each          (O)!
!           photolysis reaction defined, at each defined wavelength and     !
!           at each defined altitude level                                  !
!  JLABEL - CHARACTER*50, string identifier for each photolysis reaction (O)!
!           defined                                                         !
!---------------------------------------------------------------------------!
      IMPLICIT NONE
      INCLUDE 'params'

!---------------------------------------------------------------------------!
!     ... input                                                             !
!---------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airden(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in) ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!---------------------------------------------------------------------------!
!     ... input/output                                                      !
!---------------------------------------------------------------------------!
      integer, intent(inout) :: j

!---------------------------------------------------------------------------!
!     ... local                                                             !
!---------------------------------------------------------------------------!
      integer kdata
      parameter (kdata=300)
      integer i, n, ierr, iz, iw
      real x(kdata), y(kdata)
      real yg(kw)
      real qy

!---------------------------------------------
!     ... GLDALD (CH2(OH)CHO photolysis
!---------------------------------------------
      j = j+1
      jlabel(j) = 'GLYALD + hv -> 2HO2 + CO + CH2O'

!---------------------------------------------
!     ... GLDALD cross sections
!---------------------------------------------
      OPEN(UNIT=kin,FILE=TRIM(pn)//'XS_GLYALD.txt',
     $     STATUS='old')
      DO i = 1, 15
         READ(kin,*)
      ENDDO
      n = 131
      DO i = 1, n
         READ(kin,*) x(i), y(i)
      ENDDO
      CLOSE(kin)

      CALL addpnt(x,y,kdata,n,x(1)*(1.-deltax),0.)
      CALL addpnt(x,y,kdata,n,               0.,0.)
      CALL addpnt(x,y,kdata,n,x(n)*(1.+deltax),0.)
      CALL addpnt(x,y,kdata,n,           1.e+38,0.)
      CALL inter2(nw,wl,yg,n,x,y,ierr)
      IF (ierr .NE. 0) THEN
         WRITE(*,*) ierr, jlabel(j)
         STOP
      ENDIF

!---------------------------------------------
!     ... Combine
!---------------------------------------------
      qy = 0.5

      DO iw = 1, nw - 1
         DO i = 1, nz
            sq(j,i,iw) = yg(iw) * qy
         ENDDO
      ENDDO

      end subroutine XSQY_GLYALD
