      SUBROUTINE XSQY_MACR(nw,wl,wc,nz,tlev,airden,j,sq,jlabel,pn)
*---------------------------------------------------------------------------!
!  PURPOSE:                                                                 !
!  Provide the product (cross section) x (quantum yield) for CH2C(CH3)CHO   !
!  methacrolein        photolysis:                                          !
!           CH2C(CH3)CHO + hv -> Products                                   !
!                                                                           !
!  Cross section from                                                       !
! R. Meller, priv. comm, MPI Mainz 1990 as reported by !
! Roeth, E.-P., R. Ruhnke, G. Moortgat, R. Meller, and W. Schneider,        !
! UV/VIS-Absorption Cross Sections and QUantum Yields for Use in            !
! Photochemistry and Atmospheric Modeling, Part 2: Organic Substances,      !
! Forschungszentrum Julich, Report Jul-3341, 1997.                          !
!                                                                           !
!  Quantum yield assumed unity                                              !
*---------------------------------------------------------------------------!
!  PARAMETERS:                                                              !
!  NW     - INTEGER, number of specified intervals + 1 in working        (I)!
!           wavelength grid                                                 !
!  WL     - REAL, vector of lower limits of wavelength intervals in      (I)!
!           working wavelength grid                                         !
!  WC     - REAL, vector of center points of wavelength intervals in     (I)!
!           working wavelength grid                                         !
!  NZ     - INTEGER, number of altitude levels in working altitude grid  (I)!
!  TLEV   - REAL, temperature (K) at each specified altitude level       (I)!
!  AIRDEN - REAL, air density (molec/cc) at each altitude level          (I)!
!  J      - INTEGER, counter for number of weighting functions defined  (IO)!
!  SQ     - REAL, cross section x quantum yield (cm^2) for each          (O)!
!           photolysis reaction defined, at each defined wavelength and     !
!           at each defined altitude level                                  !
!  JLABEL - CHARACTER*50, string identifier for each photolysis reaction (O)!
!           defined                                                         !
*---------------------------------------------------------------------------!
      IMPLICIT NONE
      INCLUDE 'params'

!---------------------------------------------------------------------------!
!     ... input                                                             !
!---------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airden(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in) ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)
!
!---------------------------------------------------------------------------!
!     ... input/output                                                      !
!---------------------------------------------------------------------------!
      integer, intent(inout) :: j

!---------------------------------------------------------------------------!
!     ... local                                                             !
!---------------------------------------------------------------------------!
      integer kdata
      parameter(kdata=200)

      integer  i, n, ierr, iz, iw, idum
      real  x1(kdata), y1(kdata)
      real  yg(kw)
      real  qy
  
!----------------------------------------------
!     ... CH2C(CH3)CHO photolysis
!----------------------------------------------
      j = j+1
      jlabel(j) = 'MACR + hv -> 1.34HO2 + 0.66MCO3 + 1.34CH2O+ CH3CO3'
      j = j+1
      jlabel(j) = 'MACR + hv -> 0.66OH + 1.34CO'

!----------------------------------------------
!     ... JPL06 cross sections (Gierczak et al)
!----------------------------------------------
      open (UNIT=kin,FILE=TRIM(pn)//'XS_MACR_JPL06.txt',
     $     STATUS='old')

      read(kin,*) idum, n
      do i = 1, idum-2
        read(kin,*)
      enddo

      do i = 1, n
        read(kin,*) x1(i), y1(i)
!        print*, x1(i), y1(i)
      enddo
      close(kin)
      
      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,          0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,        1e38,0.)
      call inter2(nw,wl,yg,   n,x1,     y1,ierr)

      if (ierr .ne. 0) then
        write(*,*) ierr, jlabel(j)
        stop
      endif

!-------------------------------------------------------
!     ... Check Routine
!      do iw = 61, 87
!        print*, iw, wc(iw), yg(iw)
!      enddo
!      stop
!------------------------------------------------------
!------------------------------------------------------
!    ... Quantum yield from
!        Gierczak, T., J. B. Burkholder, R. K. Talukdar, A. 
!         Mellouki, S. B. Barone, and A. R. Ravishankara, 
!         Atmospheric fate of methyl vinyl ketone and 
!         methacrolein, J. Photochem. Photobiol A: 
!         Chemistry, 110 1-10, 1997.
!        Upper limit, quantum yield < 0.01
!------------------------------------------------------
      qy = 0.005

      DO iw = 1, nw - 1
         DO i = 1, nz
              sq(j-1,i,iw) = yg(iw) * qy 
	      sq(j,i,iw)   = yg(iw) * qy 
         ENDDO
      ENDDO

      end subroutine XSQY_MACR
