      subroutine XSQY_NOp(nw,wl,wc,nz,tlev,airlev,j,sq,jlabel,pn)
!-----------------------------------------------------------------------------!
!   purpose:                                                                  !
!   provide product (cross section) x (quantum yield):                        !
!           NO + hv = NOp + e                                                 !
!   cross section: JPL06                                                      !
!   quantum yield: is unity.                                                  !
!-----------------------------------------------------------------------------!
!   parameters:                                                               !
!   nw     - integer, number of specified intervals + 1 in working        (i) !
!            wavelength grid                                                  !
!   wl     - real, vector of lower limits of wavelength intervals in      (i) !
!            working wavelength grid                                          !
!   wc     - real, vector of center points of wavelength intervals in     (i) !
!            working wavelength grid                                          !
!   nz     - integer, number of altitude levels in working altitude grid  (i) !
!   tlev   - real, temperature (k) at each specified altitude level       (i) !
!   airlev - real, air density (molec/cc) at each altitude level          (i) !
!   j      - integer, counter for number of weighting functions defined  (io) !
!   sq     - real, cross section x quantum yield (cm^2) for each          (o) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!   jlabel - character*60, string identifier for each photolysis reaction (o) !
!            defined                                                          !
!-----------------------------------------------------------------------------!
!   edit history:                                                             !
!   01/16/08  Doug Kinnison                                                   !
!-----------------------------------------------------------------------------!
      implicit none
      include 'params'

!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airlev(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in)  ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out)         :: sq(kj,kz,kw)

!-----------------------------------------------------------------------------!
!     ... input/output                                                        !
!-----------------------------------------------------------------------------!
      integer, intent(inout) :: j

!-----------------------------------------------------------------------------!
!     ... local                                                               !
!-----------------------------------------------------------------------------!
      integer kdata
      parameter(kdata=300)
      real x1(kdata)
      real y1(kdata)
      real yg(kw)
      real qy
      integer i, iw, n, idum
      integer ierr
      integer iz

!----------------------------------------------
!     ... jlabel(j) = 'NO = hv => NOp + e'
!----------------------------------------------
      j = j+1
      jlabel(j) = 'NO + hv => NOp + e'
 
!----------------------------------------------------
!     ... Dan Marsh, Pc., 2008
!----------------------------------------------------
      DO iw = 1, nw - 1
        DO iz = 1, nz
          sq(j,iz,2) = 2.0e-18
        ENDDO
      ENDDO

!-------------------------------------------------------
!     ... Check routine 
!      do iw =1,nw-1
!        print*, iw, wc(iw), sq(j,iz,iw)
!      enddo
!      stop
!-------------------------------------------------------
      end subroutine XSQY_NOp
