      subroutine NETCDF_OUT(nz, nw, nj, wc, wl, wlintv, z, pmlev, alb, 
     $                      sza, jlabel, fnorm, sj, djdw, valj, etfphot)

!----------------------------------------------------------------------------!
!  PURPOSE:                                                                 !
!   OUTPUT J's for Ref profile                                               !
!                                                                            !
!----------------------------------------------------------------------------!
!  PARAMETERS:                                                               !
!                                                                            !
!----------------------------------------------------------------------------!
!  EDIT HISTORY:                                                             !
!  07/16/04 created - DEK                                                    !
!----------------------------------------------------------------------------!
      implicit none

      include 'params'
      include 'netcdf.inc'

!------------------------------------------------------------------------------
!       ... INPUT
!------------------------------------------------------------------------------
      integer, parameter :: numalb      = 1       ! # of albedos    
      integer, parameter :: numsza      = 1       ! # of solar zenith angles 
      integer, parameter :: nchar       = 60      ! label characters

      integer, intent(in)  :: nz                  ! # of vertical grid points
      integer, intent(in)  :: nw                  ! # of wavelength edge grid points
      integer, intent(in)  :: nj                  ! # of J's in pchem.f

      real, intent (in)    :: wc(kw-1)            ! Wavelengths (center grid)
      real, intent (in)    :: wlintv(kw)          ! Wavelength interval
      real, intent (in)    :: wl(kw)	          ! Wavelengths (edges)
      real, intent (in)    :: z(kz)		  ! Altitude (km)
      real, intent (in)    :: alb(numalb)         ! Albedo
      real, intent (in)    :: sza(numsza)         ! Zenith angle, degrees
      real, intent (in)    :: etfphot(kw)	  ! Photons cm-2 s-1 nm-1 
      real, intent (in)    :: fnorm(kz,kw)        ! fdir(iz) + fdn(iz) + fup(iz)
      real, intent (in)    :: pmlev(nz)           ! Pressure (hPa)

!     ... photolysis rate coefficient
      real, intent (in) :: valj(kj,kz)
      real, intent (in) :: djdw(kj,kz,kw)         ! wavelength dependent Js
      real, intent (in) :: sj  (kj,kz,kw)         ! cross sections

      CHARACTER*60 jlabel(nj)			  ! photolysis label
      CHARACTER*60 jlabel_ex		   	  ! output photolysis label

!------------------------------------------------------------------------------
!       ... Local variables
!------------------------------------------------------------------------------
!     wavelength length
      integer :: iw, ialb, io3, isza, iz, ij, np
      real jcoeff       (nj,nz)
      real jcoeff_wc    (nj,nz,nw-1)
      real cross_section(nj,nz,nw-1)
      real etf          (nj)
      real norm_flux    (nz,nw-1)

!------------------------------------------------------------------------------
!       ... NetCDF IDs
!------------------------------------------------------------------------------
      integer :: ncid
      integer :: iret

!------------------------------------------------------------------------------
!       ... Dimension IDs
!------------------------------------------------------------------------------
      integer :: wcdim
      integer :: colo3dim
      integer :: albdim
      integer :: szadim
      integer :: zdim
      integer :: nschar
      integer :: jdim
      integer :: prsdim

!------------------------------------------------------------------------------
!       ... Variable IDs
!------------------------------------------------------------------------------
      integer :: rsf_id
      integer :: nflx_id
      integer :: xs_id
      integer :: djdw_id
      integer :: wave_id
      integer :: wcid
      integer :: alb_id
      integer :: colo3_id
      integer :: z_id
      integer :: sza_id
      integer :: etfphot_id
      integer :: label_id
      integer :: start(2)
      integer :: count(2)
      integer :: j_id

      integer :: jo2_a_id,    jo2_b_id,     jo3_a_id,     jo3_b_id
      integer :: jn2o_id
      integer :: jno_id,      jno2_id,      jn2o5_a_id,   jn2o5_b_id
      integer :: jhno3_id,    jno3_a_id,    jno3_b_id,    jho2no2_a_id
      integer :: jho2no2_b_id,jch3ooh_id,   jch2o_a_id,   jch2o_b_id
      integer :: jh2o_a_id,   jh2o_b_id,    jh2o_c_id,    jh2o2_id
      integer :: jcl2_id,     joclo_id,     jcl2o2_id,    jhocl_id
      integer :: jhcl_id,     jclono2_a_id, jclono2_b_id, jbrcl_id
      integer :: jbro_id,     jhobr_id,     jbrono2_a_id, jbrono2_b_id
      integer :: jch3cl_id,   jccl4_id,     jch3ccl3_id,  jcfcl3_id
      integer :: jcf2cl2_id,  jcfc113_id,   jhcfc22_id,   jch3br_id
      integer :: jcf3br_id,   jcf2clbr_id,  jco2_id,      jch4_a_id
      integer :: jch4_b_id   
      integer :: jch3cho_id,  jpan_id,      jmacr_a_id,   jmacr_b_id
      integer :: jmvk_id,     jacet_id,     jmgly_id,     jhyac_id
      integer :: jglyald_id,  jch3o2no2_id, jhono_id,     jho2_id
      integer :: jhbr_id,     jbr2_id,      jh2402_id,    jch2br2_id
      integer :: jclo_id,     jso2_id,      jso3_id,      jso_id 
      integer :: jh2so4_id,   jcs2_id,      jocs_id,      jno_i_id
      integer :: jbrono_id,   jbrno2_id,    ji2_id,       jio_id
      integer :: joio_id,     jino_id,      jiono_id,     jiono2_id
      integer :: jhoi_id,     jibr_id,      jicl_id,      jchbr3_id
      integer :: jch2brcl_id, jchbr2cl_id,  jchbrcl2_id,  jch3i_id
      integer :: jch2i2_id,   jch2ibr_id,   jch2icl_id,   jc2h5i_id
      integer :: jch3chi2_id, jc3h7i_id,    jc4h9i_id,    jclono_id
      integer :: jclno2_id,   jhno3nat_id,  jhno3sts_id,  jcfc114_id
      integer :: jcfc115_id,  jh1202_id,    jhcfc141b_id, jhcfc142b_id
      integer :: jcof2_id,    jcofcl_id,    jhf_id,       ji2o2_id
      integer :: ji2o3_id,    ji2o4_id,     jsf6_id,      jhi_id

      
!------------------------------------------------------------------------------
!       ... Variable Shapes
!------------------------------------------------------------------------------
      integer :: dims(3)

      np = nz

      print*,nj,nz,np, nw
 

!------------------------------------------------------------------------------
!       ... Extract
!------------------------------------------------------------------------------
      do ij = 1, nj
        do iz = 1, nz
           jcoeff(ij,iz) = valj(ij,iz)
        enddo
      enddo

      do iz = 1, nz
        do iw = 1, nw-1
           norm_flux(iz,iw) = fnorm(iz,iw)
        enddo
      enddo

      do iw = 1, nw-1
       do ij = 1, nj
        do iz = 1, nz
           jcoeff_wc(ij,iz,iw) = djdw(ij,iz,iw)
        enddo
       enddo
      enddo

      do iw = 1, nw-1
       do ij = 1, nj
        do iz = 1, nz
           cross_section(ij,iz,iw) = sj(ij,iz,iw)
        enddo
       enddo
      enddo
            
      do iw = 1, nw-1
        etf(iw) = etfphot(iw)
      enddo

!------------------------------------------------------------------------------
!       ... Enter Define Mode
!------------------------------------------------------------------------------
      iret = nf_create ('ref_profile_jpl10.nc', nf_clobber, ncid)
      if (iret /= nf_noerr) then 
	  print*,"nf_create failed"
	  stop
      end if

!------------------------------------------------------------------------------
!       ... Define Dimensions
!------------------------------------------------------------------------------
      wcdim          = ncddef(ncid, 'numwl',        nw-1,   iret)
      zdim           = ncddef(ncid, 'numz',         nz,     iret)
      szadim         = ncddef(ncid, 'numsza',       numsza, iret)
      albdim         = ncddef(ncid, 'numalb',       numalb, iret)
      jdim           = ncddef(ncid, 'numj',         nj,     iret)
      nschar         = ncddef(ncid, 'numchar',      nchar,  iret)
      prsdim         = ncddef(ncid, 'numprs' ,      np,     iret)

!------------------------------------------------------------------------------
!       ... Define Variables
!------------------------------------------------------------------------------
!     .... Photolysis Labels
      dims(1) = nschar
      dims(2) = jdim
      iret = ncvdef(ncid, 'jlabels', NCCHAR, 2, dims, iret)
      iret = nf_inq_varid(ncid, "jlabels", label_id)
      iret = nf_put_att_text(ncid, label_id, 'long_name', 19,
     $                  "Photolysis Species")

!     .... Wavelength Grid
      dims(1) = wcdim
      iret = ncvdef(ncid, 'wc', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, "wc", wave_id)
      iret = nf_put_att_text(ncid, wave_id, 'long_name', 22,
     $                  "Wavelength Grid Center")
      iret = nf_put_att_text(ncid, wave_id, 'units', 2, 
     $                         "nm")

!     .... Wavelength Grid Inteval
      dims(1) = wcdim
      iret = ncvdef(ncid, 'wlintv', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, "wlintv", wave_id)
      iret = nf_put_att_text(ncid, wave_id, 'long_name', 26,
     $                  "Wavelength Grid Interval")
      iret = nf_put_att_text(ncid, wave_id, 'units', 2, 
     $                         "nm")

!     .... Z Grid
      dims(1) = zdim
      iret = ncvdef(ncid, 'z', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, "z", z_id)
	iret = nf_put_att_text(ncid, z_id, 'long_name', 8,
     $                  "Altitude")
      iret = nf_put_att_text(ncid, z_id, 'units', 2, 
     $                         "km")

!     .... Pressure Grid
      dims(1) = zdim
      iret = ncvdef(ncid, 'pm', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, "pm", z_id)
      iret = nf_put_att_text(ncid, z_id, 'long_name', 8,
     $                  "Altitude")
      iret = nf_put_att_text(ncid, z_id, 'units', 3, 
     $                         "hPa")

!     .... SZA
      dims(1) = szadim
      iret = ncvdef(ncid, 'sza', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, "sza", sza_id)
      iret = nf_put_att_text(ncid, sza_id, 'long_name', 18,
     $                  "Solar Zenith Angle")
      iret = nf_put_att_text(ncid, sza_id, 'units', 7, 
     $                         "Degrees")

!     .... Albedo
      dims(1) = albdim
      iret = ncvdef(ncid, 'alb', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, "alb", alb_id)
      iret = nf_put_att_text(ncid, alb_id, 'long_name', 6,
     $                  "Albedo")

!     .... Extra Terrestrial Photons 
      dims(1) = wcdim
      iret = ncvdef(ncid, 'etfphot', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, "etfphot", etfphot_id)
      iret = nf_put_att_text(ncid, etfphot_id, 'long_name', 22,
     $                  "Extra Terrestrial Flux")
      iret = nf_put_att_text(ncid, etfphot_id, 'units', 23, 
     $                         "Photons cm-2 sec-1 nm-1")

!     .... Normalize Flux (iz,iw)

      dims(2) = wcdim
      dims(1) = zdim
      iret = ncvdef(ncid, 'norm_flux', NCFLOAT, 2, dims, iret)
      iret = nf_inq_varid(ncid, "norm_flux", nflx_id)
      iret = nf_put_att_text(ncid, nflx_id, 'long_name', 22,
     $                  "Normalize Actinic Flux")
      iret = nf_put_att_text(ncid, nflx_id, 'units', 8, 
     $                         "unitless")  

!     .... jcoeff(ij,iz)
!
      dims(2) = zdim
      dims(1) = jdim
      iret = ncvdef(ncid, 'jcoeff', NCFLOAT, 2, dims, iret)
      iret = nf_inq_varid(ncid, "jcoeff", rsf_id)
      iret = nf_put_att_text(ncid, rsf_id, 'long_name', 24,
     $                  "Photolysis Rate Constant")
      iret = nf_put_att_text(ncid, rsf_id, 'units', 5, 
     $                         "sec-1")

!     .... jcoeff_wc(ij,iz,iw)
      dims(3) = wcdim
      dims(2) = zdim
      dims(1) = jdim
      iret = ncvdef(ncid, 'jcoeff_wc', NCFLOAT, 3, dims, iret)
      iret = nf_inq_varid(ncid, "jcoeff_wc", djdw_id)
      iret = nf_put_att_text(ncid, djdw_id, 'long_name', 24,
     $                  "Photolysis Rate Constant")
      iret = nf_put_att_text(ncid, djdw_id, 'units', 5, 
     $                         "sec-1")

!     .... cross sections(ij,iz,iw)
      dims(3) = wcdim
      dims(2) = zdim
      dims(1) = jdim
      iret = ncvdef(ncid, 'cross_section', NCFLOAT, 3, dims, iret)
      iret = nf_inq_varid(ncid, "cross_section", xs_id)
      iret = nf_put_att_text(ncid, xs_id, 'long_name', 24,
     $                  "Photolysis Rate Constant")
      iret = nf_put_att_text(ncid, xs_id, 'units', 5, 
     $                         "sec-1")

!================================================================================
!... O2 and Ox based species... Profiles
!================================================================================
!     .... JO2 = O + O1D
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jo2_a', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jo2_a', jo2_a_id)
      iret = nf_put_att_text(ncid, jo2_a_id, 'long_name', 18,
     $                  "O2 + hv => O + O1D" )
      iret = nf_put_att_text(ncid, jo2_a_id, 'units', 5, 
     $                         "sec-1")
!     .... JO2 = 20
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jo2_b', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jo2_b', jo2_b_id)
      iret = nf_put_att_text(ncid, jo2_b_id, 'long_name', 16,
     $                  "O2 + hv => O + O" )
      iret = nf_put_att_text(ncid, jo2_b_id, 'units', 5, 
     $                         "sec-1")
!     .... JO3 = O2_1D + O1D
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jo3_a', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jo3_a', jo3_a_id)
      iret = nf_put_att_text(ncid, jo3_a_id, 'long_name', 22,
     $                  "O3 + hv => O2_1D + O1D" )
      iret = nf_put_att_text(ncid, jo3_a_id, 'units', 5, 
     $                         "sec-1")
!     .... JO3 = O2 + O
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jo3_b', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jo3_b', jo3_b_id)
      iret = nf_put_att_text(ncid, jo3_b_id, 'long_name', 17,
     $                  "O3 + hv => O2 + O" )
      iret = nf_put_att_text(ncid, jo3_b_id, 'units', 5, 
     $                         "sec-1")

!================================================================================
!... Inorganic Nitrogen and N2O based species...
!================================================================================
!     .... JN2O = N2 + O1D
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jn2o', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jn2o', jn2o_id)
      iret = nf_put_att_text(ncid, jn2o_id, 'long_name', 20,
     $                  "N2O + hv => N2 + O1D" )
      iret = nf_put_att_text(ncid, jn2o_id, 'units', 5, 
     $                         "sec-1")
!     .... JNO = N + O
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jno', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jno', jno_id)
      iret = nf_put_att_text(ncid, jno_id, 'long_name', 16,
     $                  "NO + hv => N + O" )
      iret = nf_put_att_text(ncid, jno_id, 'units', 5, 
     $                         "sec-1")
!     .... JNO2 = NO + O
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jno2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jno2', jno2_id)
      iret = nf_put_att_text(ncid, jno2_id, 'long_name', 18,
     $                  "NO2 + hv => NO + O" )
      iret = nf_put_att_text(ncid, jno2_id, 'units', 5, 
     $                         "sec-1")
!     .... JN2O5 = NO2 + NO3
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jn2o5_a', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jn2o5_a', jn2o5_a_id)
      iret = nf_put_att_text(ncid, jn2o5_a_id, 'long_name', 22,
     $                  "N2O5 + hv => NO2 + NO3" )
      iret = nf_put_att_text(ncid, jn2o5_a_id, 'units', 5, 
     $                         "sec-1")
!     .... JN2O5 = NO + O + NO3
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jn2o5_b', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jn2o5_b', jn2o5_b_id)
      iret = nf_put_att_text(ncid, jn2o5_b_id, 'long_name', 25,
     $                  "N2O5 + hv => NO + O + NO3" )
      iret = nf_put_att_text(ncid, jn2o5_b_id, 'units', 5, 
     $                         "sec-1")
!     .... JHNO3 = OH + NO2
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jhno3', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jhno3', jhno3_id)
      iret = nf_put_att_text(ncid, jhno3_id, 'long_name', 21,
     $                  "HNO3 + hv => OH + NO2" )
      iret = nf_put_att_text(ncid, jhno3_id, 'units', 5, 
     $                         "sec-1")
!     .... JHNO3NAT = NO2 + OH
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jhno3nat', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jhno3nat', jhno3nat_id)
      iret = nf_put_att_text(ncid, jhno3nat_id, 'long_name', 24,
     $                  "HNO3NAT + hv => NO2 + OH" )
      iret = nf_put_att_text(ncid, jhno3nat_id, 'units', 5, 
     $                         "sec-1")

!     .... JHNO3STS = NO2 + OH
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jhno3sts', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jhno3sts', jhno3sts_id)
      iret = nf_put_att_text(ncid, jhno3sts_id, 'long_name', 24,
     $                  "HNO3STS + hv => NO2 + OH" )
      iret = nf_put_att_text(ncid, jhno3sts_id, 'units', 5, 
     $                         "sec-1")

!     .... JNO3 = NO2 + O
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jno3_a', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jno3_a', jno3_a_id)
      iret = nf_put_att_text(ncid, jno3_a_id, 'long_name', 19,
     $                  "NO3 + hv => NO2 + O" )
      iret = nf_put_att_text(ncid, jno3_a_id, 'units', 5, 
     $                         "sec-1")
!     .... JNO3 = NO + O2
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jno3_b', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jno3_b', jno3_b_id)
      iret = nf_put_att_text(ncid, jno3_b_id, 'long_name', 19,
     $                  "NO3 + hv => NO + O2" )
      iret = nf_put_att_text(ncid, jno3_b_id, 'units', 5, 
     $                         "sec-1")
!     .... JHO2NO2 = OH + NO3
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jho2no2_a', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jho2no2_a', jho2no2_a_id)
      iret = nf_put_att_text(ncid, jho2no2_a_id, 'long_name', 23,
     $                  "HO2NO2 + hv => OH + NO3" )
      iret = nf_put_att_text(ncid, jho2no2_a_id, 'units', 5, 
     $                         "sec-1")
!     .... JHO2NO2 = HO2 + NO2
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jho2no2_b', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jho2no2_b', jho2no2_b_id)
      iret = nf_put_att_text(ncid, jho2no2_b_id, 'long_name', 24,
     $                  "HO2NO2 + hv => HO2 + NO2" )
      iret = nf_put_att_text(ncid, jho2no2_b_id, 'units', 5, 
     $                         "sec-1")
!     .... JHONO= OH + NO"
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jhono', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jhono', jhono_id)
      iret = nf_put_att_text(ncid, jhono_id, 'long_name', 19,
     $                  "HONO + hv = OH + NO" )
      iret = nf_put_att_text(ncid,jhono_id, 'units', 5, 
     $                         "sec-1")

!================================================================================
!... Inorganic hydrogen and H2O  based species...
!================================================================================
!     .... JH2O = H + OH
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jh2o_a', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jh2o_a', jh2o_a_id)
      iret = nf_put_att_text(ncid, jh2o_a_id, 'long_name', 18,
     $                  "H2O + hv => H + OH" )
      iret = nf_put_att_text(ncid, jh2o_a_id, 'units', 5, 
     $                         "sec-1")
!     .... JH2O = H2 + O1D
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jh2o_b', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jh2o_b', jh2o_b_id)
      iret = nf_put_att_text(ncid, jh2o_b_id, 'long_name', 20,
     $                  "H2O + hv => H2 + O1D" )
      iret = nf_put_att_text(ncid, jh2o_b_id, 'units', 5, 
     $                         "sec-1")
!     .... JH2O = 2H + O
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jh2o_c', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jh2o_c', jh2o_c_id)
      iret = nf_put_att_text(ncid, jh2o_c_id, 'long_name', 18,
     $                  "H2O + hv => 2H + O" )
      iret = nf_put_att_text(ncid, jh2o_c_id, 'units', 5, 
     $                         "sec-1")
!     .... JH2O2 = 2OH
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jh2o2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jh2o2', jh2o2_id)
      iret = nf_put_att_text(ncid, jh2o2_id, 'long_name', 16,
     $                  "H2O2 + hv => 2OH" )
      iret = nf_put_att_text(ncid, jh2o2_id, 'units', 5, 
     $                         "sec-1")
!     .... JHO2 = OH + O
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jho2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jho2', jho2_id)
      iret = nf_put_att_text(ncid, jho2_id, 'long_name', 17,
     $                  "HO2 + hv = OH + O" )
      iret = nf_put_att_text(ncid,jho2_id, 'units', 5, 
     $                         "sec-1")

!================================================================================
!... Inorganic chlorine based species...
!================================================================================
!     .... JCl2 = 2Cl
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jcl2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jcl2', jcl2_id)
      iret = nf_put_att_text(ncid, jcl2_id, 'long_name', 15,
     $                  "Cl2 + hv => 2Cl" )
      iret = nf_put_att_text(ncid, jcl2_id, 'units', 5, 
     $                         "sec-1")
!     .... JClO = Cl + O
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jclo', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jclo', jclo_id)
      iret = nf_put_att_text(ncid, jclo_id, 'long_name', 18,
     $                  "ClO + hv => Cl + O" )
      iret = nf_put_att_text(ncid, jclo_id, 'units', 5, 
     $                         "sec-1")

!     .... JOClO = ClO + O
	dims(1) = prsdim
      iret = ncvdef(ncid, 'joclo', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'joclo', joclo_id)
      iret = nf_put_att_text(ncid, joclo_id, 'long_name', 20,
     $                  "OClO + hv => ClO + O" )
      iret = nf_put_att_text(ncid, joclo_id, 'units', 5, 
     $                         "sec-1")
!     .... JCl2O2
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jcl2o2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jcl2o2', jcl2o2_id)
      iret = nf_put_att_text(ncid, jcl2o2_id, 'long_name', 23,
     $                  "Cl2O2 + hv => Cl + ClOO" )
      iret = nf_put_att_text(ncid, jcl2o2_id, 'units', 5, 
     $                         "sec-1")
!     .... JHOCl = OH + Cl
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jhocl', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jhocl', jhocl_id)
      iret = nf_put_att_text(ncid, jhocl_id, 'long_name', 20,
     $                  "HOCl + hv => OH + Cl" )
      iret = nf_put_att_text(ncid, jhocl_id, 'units', 5, 
     $                         "sec-1")
!     .... JHCl = H + Cl
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jhcl', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jhcl', jhcl_id)
      iret = nf_put_att_text(ncid, jhcl_id, 'long_name', 18,
     $                  "HCl + hv => H + Cl" )
      iret = nf_put_att_text(ncid, jhcl_id, 'units', 5, 
     $                         "sec-1")
!     .... JClNO2 = Cl + NO2
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jclno2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jclno2', jclno2_id)
      iret = nf_put_att_text(ncid, jclno2_id, 'long_name', 22,
     $                  "ClNO2 + hv => Cl + NO2" )
      iret = nf_put_att_text(ncid, jclno2_id, 'units', 5, 
     $                         "sec-1")
!     .... JClONO = Cl + NO2
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jclono', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jclono', jclono_id)
      iret = nf_put_att_text(ncid, jclono_id, 'long_name', 22,
     $                  "ClONO + hv => Cl + NO2" )
      iret = nf_put_att_text(ncid, jclono_id, 'units', 5, 
     $                         "sec-1")
!     .... JClONO2 = Cl + NO3
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jclono2_a', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jclono2_a', jclono2_a_id)
      iret = nf_put_att_text(ncid, jclono2_a_id, 'long_name', 24,
     $                  "ClONO2 + hv => Cl + NO3" )
      iret = nf_put_att_text(ncid, jclono2_a_id, 'units', 5, 
     $                         "sec-1")

!     .... JClONO2 = ClO + NO2
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jclono2_b', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jclono2_b', jclono2_b_id)
      iret = nf_put_att_text(ncid, jclono2_b_id, 'long_name', 24,
     $                  "ClONO2 + hv => ClO + NO2" )
      iret = nf_put_att_text(ncid, jclono2_b_id, 'units', 5, 
     $                         "sec-1")

!================================================================================
!... Inorganic Bromine based species...
!================================================================================
!     .... JBrCl = Br + Cl
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jbrcl', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jbrcl', jbrcl_id)
      iret = nf_put_att_text(ncid, jbrcl_id, 'long_name', 20,
     $                  "BrCl + hv => Br + Cl" )
      iret = nf_put_att_text(ncid, jbrcl_id, 'units', 5, 
     $                         "sec-1")
!     .... JBr2 = 2Br
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jbr2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jbr2', jbr2_id)
      iret = nf_put_att_text(ncid, jbr2_id, 'long_name', 14,
     $                  "Br2 + hv = 2Br" )
      iret = nf_put_att_text(ncid,jbr2_id, 'units', 5, 
     $                         "sec-1")
!     .... JBrO = Br + O
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jbro', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jbro', jbro_id)
      iret = nf_put_att_text(ncid, jbro_id, 'long_name', 18,
     $                  "BrO + hv => Br + O" )
      iret = nf_put_att_text(ncid, jbro_id, 'units', 5, 
     $                         "sec-1")
!     .... JHOBr = OH + Br
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jhobr', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jhobr', jhobr_id)
      iret = nf_put_att_text(ncid, jhobr_id, 'long_name', 20,
     $                  "HOBr + hv => OH + Br" )
      iret = nf_put_att_text(ncid, jhobr_id, 'units', 5, 
     $                         "sec-1")
!     .... JHBr = H + Br
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jhbr', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jhbr', jhbr_id)
      iret = nf_put_att_text(ncid, jhbr_id, 'long_name', 17,
     $                  "HBr + hv = H + Br" )
      iret = nf_put_att_text(ncid,jhbr_id, 'units', 5, 
     $                         "sec-1")
!     .... JBrONO = Br + NO2
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jbrono', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jbrono', jbrono_id)
      iret = nf_put_att_text(ncid, jbrono_id, 'long_name', 22,
     $                  "BrONO + hv => Br + NO2" )
      iret = nf_put_att_text(ncid, jbrono_id, 'units', 5, 
     $                         "sec-1")
!     .... JBrNO2 = Br + NO2
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jbrno2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jbrno2', jbrno2_id)
      iret = nf_put_att_text(ncid, jbrno2_id, 'long_name', 22,
     $                  "BrNO2 + hv => Br + NO2" )
      iret = nf_put_att_text(ncid, jbrno2_id, 'units', 5, 
     $                         "sec-1")
!     .... JBrONO2 = Br + NO3
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jbrono2_a', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jbrono2_a', jbrono2_a_id)
      iret = nf_put_att_text(ncid, jbrono2_a_id, 'long_name', 23,
     $                  "BrONO2 + hv => Br + NO3" )
      iret = nf_put_att_text(ncid, jbrono2_b_id, 'units', 5, 
     $                         "sec-1")
!     .... JBrONO2 = BrO + NO2
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jbrono2_b', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jbrono2_b', jbrono2_b_id)
      iret = nf_put_att_text(ncid, jbrono2_b_id, 'long_name', 24,
     $                  "BrONO2 + hv => BrO + NO2" )
      iret = nf_put_att_text(ncid, jbrono2_b_id, 'units', 5, 
     $                         "sec-1")

!================================================================================
!... Inorganic Iodine based species...
!================================================================================
!     .... JI2 = 2I
	dims(1) = prsdim
      iret = ncvdef(ncid, 'ji2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'ji2', ji2_id)
      iret = nf_put_att_text(ncid, ji2_id, 'long_name', 13,
     $                  "I2 + hv => 2I" )
      iret = nf_put_att_text(ncid, ji2_id, 'units', 5, 
     $                         "sec-1")
!     .... JIO = I + O
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jio', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jio', jio_id)
      iret = nf_put_att_text(ncid, jio_id, 'long_name', 16,
     $                  "IO + hv => I + O" )
      iret = nf_put_att_text(ncid, jio_id, 'units', 5, 
     $                         "sec-1")
!     .... JOIO = I + O2
	dims(1) = prsdim
      iret = ncvdef(ncid, 'joio', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'joio', joio_id)
      iret = nf_put_att_text(ncid, joio_id, 'long_name', 18,
     $                  "OIO + hv => I + O2" )
      iret = nf_put_att_text(ncid, joio_id, 'units', 5, 
     $                         "sec-1")
!     .... JINO = I + NO
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jino', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jino', jino_id)
      iret = nf_put_att_text(ncid, jino_id, 'long_name', 18,
     $                  "INO + hv => I + NO" )
      iret = nf_put_att_text(ncid, jino_id, 'units', 5, 
     $                         "sec-1")
     
!     .... JIONO = I + NO2
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jiono', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jiono', jiono_id)
      iret = nf_put_att_text(ncid, jiono_id, 'long_name', 20,
     $                  "IONO + hv => I + NO2" )
      iret = nf_put_att_text(ncid, jiono_id, 'units', 5, 
     $                         "sec-1")
!     .... JIONO2 = I + NO3
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jiono2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jiono2', jiono2_id)
      iret = nf_put_att_text(ncid, jiono2_id, 'long_name', 21,
     $                  "IONO2 + hv => I + NO3" )
      iret = nf_put_att_text(ncid, jiono2_id, 'units', 5, 
     $                         "sec-1")
!     .... JHOI = I + OH
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jhoi', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jhoi', jhoi_id)
      iret = nf_put_att_text(ncid, jhoi_id, 'long_name', 18,
     $                  "HOI + hv => I + OH" )
      iret = nf_put_att_text(ncid, jhoi_id, 'units', 5, 
     $                         "sec-1")
!     .... JHI = I + H
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jhi', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jhi', jhi_id)
      iret = nf_put_att_text(ncid, jhi_id, 'long_name', 16,
     $                  "HI + hv => I + H" )
      iret = nf_put_att_text(ncid, jhi_id, 'units', 5, 
     $                         "sec-1")
!     .... JIBr = I + Br
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jibr', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jibr', jibr_id)
      iret = nf_put_att_text(ncid, jibr_id, 'long_name', 18,
     $                  "IBr + hv => I + Br" )
      iret = nf_put_att_text(ncid, jibr_id, 'units', 5, 
     $                         "sec-1")
!     .... JICl = I + Cl
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jicl', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jicl', jicl_id)
      iret = nf_put_att_text(ncid, jicl_id, 'long_name', 18,
     $                  "ICl + hv => I + Cl" )
      iret = nf_put_att_text(ncid, jicl_id, 'units', 5, 
     $                         "sec-1")
!     .... JI2O2 = OIO + I
	dims(1) = prsdim
      iret = ncvdef(ncid, 'ji2o2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'ji2o2', ji2o2_id)
      iret = nf_put_att_text(ncid, ji2o2_id, 'long_name', 21,
     $                  "I2O2 + hv => OIO + I" )
      iret = nf_put_att_text(ncid, ji2o2_id, 'units', 5, 
     $                         "sec-1")
!     .... JI2O3 = OIO + IO
	dims(1) = prsdim
      iret = ncvdef(ncid, 'ji2o3', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'ji2o3', ji2o3_id)
      iret = nf_put_att_text(ncid, ji2o3_id, 'long_name', 22,
     $                  "I2O3 + hv => OIO + IO" )
      iret = nf_put_att_text(ncid, ji2o3_id, 'units', 5, 
     $                         "sec-1")
!     .... JI2O4 = OIO + OIO
	dims(1) = prsdim
      iret = ncvdef(ncid, 'ji2o4', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'ji2o4', ji2o4_id)
      iret = nf_put_att_text(ncid, ji2o4_id, 'long_name', 23,
     $                  "I2O4 + hv => OIO + OIO" )
      iret = nf_put_att_text(ncid, ji2o4_id, 'units', 5, 
     $                         "sec-1")

!================================================================================
!... Inorganic Florine based species...
!================================================================================
!     .... JCOFCl = F + Cl
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jcofcl', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jcofcl', jcofcl_id)
      iret = nf_put_att_text(ncid, jcofcl_id, 'long_name', 20,
     $                  "COFCl + hv => F + Cl" )
      iret = nf_put_att_text(ncid, jcofcl_id, 'units', 5, 
     $                         "sec-1")
!     .... JCOF2 = 2F 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jcof2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jcof2', jcof2_id)
      iret = nf_put_att_text(ncid, jcof2_id, 'long_name', 15,
     $                  "COF2 + hv => 2F" )
      iret = nf_put_att_text(ncid, jcof2_id, 'units', 5, 
     $                         "sec-1")
!     .... JHF = H + F 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jhf', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jhf', jhf_id)
      iret = nf_put_att_text(ncid, jhf_id, 'long_name', 16,
     $                  "HF + hv => H + F" )
      iret = nf_put_att_text(ncid, jhf_id, 'units', 5, 
     $                         "sec-1")

!================================================================================
!... Organic Chlorine based species...
!================================================================================
!     .... JCH3Cl = Cl + CH3O2
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jch3cl', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jch3cl', jch3cl_id)
      iret = nf_put_att_text(ncid, jch3cl_id, 'long_name', 16,
     $                  "CH3Cl + hv => Cl" )
      iret = nf_put_att_text(ncid, jch3cl_id, 'units', 5, 
     $                         "sec-1")
!     .... JCCl4 = 4Cl 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jccl4', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jccl4', jccl4_id)
      iret = nf_put_att_text(ncid, jccl4_id, 'long_name', 16,
     $                  "CCl4 + hv => 4Cl" )
      iret = nf_put_att_text(ncid, jccl4_id, 'units', 5, 
     $                         "sec-1")
!     .... JCH3CCl3 = 3Cl 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jch3ccl3', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jch3ccl3', jch3ccl3_id)
      iret = nf_put_att_text(ncid, jch3ccl3_id, 'long_name', 19,
     $                  "CH3CCl3 + hv => 3Cl" )
      iret = nf_put_att_text(ncid, jch3ccl3_id, 'units', 5, 
     $                         "sec-1")
!     .... JCFCl3 = 3Cl 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jcfcl3', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jcfcl3', jcfcl3_id)
      iret = nf_put_att_text(ncid, jcfcl3_id, 'long_name', 17,
     $                  "CFCl3 + hv => 3Cl" )
      iret = nf_put_att_text(ncid, jcfcl3_id, 'units', 5, 
     $                         "sec-1")
!     .... JCF2Cl2 = 2Cl 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jcf2cl2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jcf2cl2', jcf2cl2_id)
      iret = nf_put_att_text(ncid, jcf2cl2_id, 'long_name', 18,
     $                  "CF2Cl2 + hv => 2Cl" )
      iret = nf_put_att_text(ncid, jcf2cl2_id, 'units', 5, 
     $                         "sec-1")
!     .... JCFC113 = 3Cl 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jcfc113', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jcfc113', jcfc113_id)
      iret = nf_put_att_text(ncid, jcfc113_id, 'long_name', 18,
     $                  "CFC113 + hv => 3Cl" )
      iret = nf_put_att_text(ncid, jcfc113_id, 'units', 5, 
     $                         "sec-1")
!     .... JHCFC22 = Cl 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jhcfc22', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jhcfc22', jhcfc22_id)
      iret = nf_put_att_text(ncid, jhcfc22_id, 'long_name', 17,
     $                  "HCFC22 + hv => Cl" )
      iret = nf_put_att_text(ncid, jhcfc22_id, 'units', 5, 
     $                         "sec-1")
!     .... JCFC114 = 2Cl 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jcfc114', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jcfc114', jcfc114_id)
      iret = nf_put_att_text(ncid, jcfc114_id, 'long_name', 18,
     $                  "CFC114 + hv => 2Cl" )
      iret = nf_put_att_text(ncid, jcfc114_id, 'units', 5, 
     $                         "sec-1")
!     .... JCFC115 = Cl 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jcfc115', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jcfc115', jcfc115_id)
      iret = nf_put_att_text(ncid, jcfc115_id, 'long_name', 18,
     $                  "CFC115 + hv => Cl" )
      iret = nf_put_att_text(ncid, jcfc115_id, 'units', 5, 
     $                         "sec-1")
!     .... JHCFC141b = 2Cl 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jhcfc141b', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jhcfc141b', jhcfc141b_id)
      iret = nf_put_att_text(ncid, jhcfc141b_id, 'long_name', 20,
     $                  "HCFC141b + hv => 2Cl" )
      iret = nf_put_att_text(ncid, jhcfc141b_id, 'units', 5, 
     $                         "sec-1")
!     .... JHCFC142b = Cl 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jhcfc142b', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jhcfc142b', jhcfc142b_id)
      iret = nf_put_att_text(ncid, jhcfc142b_id, 'long_name', 20,
     $                  "HCFC142b + hv => Cl" )
      iret = nf_put_att_text(ncid, jhcfc142b_id, 'units', 5, 
     $                         "sec-1")

!================================================================================
!... Organic Bromine based species...
!================================================================================
!     .... JCH3Br = Br 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jch3br', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jch3br', jch3br_id)
      iret = nf_put_att_text(ncid, jch3br_id, 'long_name', 16,
     $                  "CH3Br + hv => Br" )
      iret = nf_put_att_text(ncid, jch3br_id, 'units', 5, 
     $                         "sec-1")
!     .... JCF3Br = Br  (Halon-1301)
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jcf3br', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jcf3br', jcf3br_id)
      iret = nf_put_att_text(ncid, jcf3br_id, 'long_name', 16,
     $                  "CF3Br + hv => Br" )
      iret = nf_put_att_text(ncid, jcf3br_id, 'units', 5, 
     $                         "sec-1")
!     .... JCF2ClBr = Br + Cl  (Halon-1211)
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jcf2clbr', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jcf2clbr', jcf2clbr_id)
      iret = nf_put_att_text(ncid, jcf2clbr_id, 'long_name', 23,
     $                  "CF2ClBr + hv => Br + Cl" )
      iret = nf_put_att_text(ncid, jcf2clbr_id, 'units', 5, 
     $                         "sec-1")
!     .... JH2402 = 2Br
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jh2402', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jh2402', jh2402_id)
      iret = nf_put_att_text(ncid, jh2402_id, 'long_name', 29,
     $                  "CF2BrCF2Br (H2402) + hv = 2Br" )
      iret = nf_put_att_text(ncid,jh2402_id, 'units', 5, 
     $                         "sec-1")
!     .... JCH2BR2 = 2Br
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jch2br2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jch2br2', jch2br2_id)
      iret = nf_put_att_text(ncid, jch2br2_id, 'long_name', 29,
     $                  "CH2Br2 (bromoform) + hv = 2Br" )
      iret = nf_put_att_text(ncid,jch2br2_id, 'units', 5, 
     $                         "sec-1")
!     .... JCHBR3 = 3Br
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jchbr3', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jchbr3', jchbr3_id)
      iret = nf_put_att_text(ncid, jchbr3_id, 'long_name', 16,
     $                  "CHBr3 + hv = 3Br" )
      iret = nf_put_att_text(ncid,jchbr3_id, 'units', 5, 
     $                         "sec-1")
!     .... JCH2BrCl = Br + Cl
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jch2brcl', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jch2brcl', jch2brcl_id)
      iret = nf_put_att_text(ncid, jch2brcl_id, 'long_name', 22,
     $                  "CH2BrCl + hv = Br + Cl" )
      iret = nf_put_att_text(ncid,jch2brcl_id, 'units', 5, 
     $                         "sec-1")
!     .... JCHBr2Cl = 2Br + Cl
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jchbr2cl', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jchbr2cl', jchbr2cl_id)
      iret = nf_put_att_text(ncid, jchbr2cl_id, 'long_name', 23,
     $                  "CHBr2Cl + hv = 2Br + Cl" )
      iret = nf_put_att_text(ncid,jchbr2cl_id, 'units', 5, 
     $                         "sec-1")
!     .... JCHBrCl2 = Br + 2Cl
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jchbrcl2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jchbrcl2', jchbrcl2_id)
      iret = nf_put_att_text(ncid, jchbr2cl_id, 'long_name', 23,
     $                  "CHBrCl2 + hv = Br + 2Cl" )
      iret = nf_put_att_text(ncid,jchbrcl2_id, 'units', 5, 
     $                         "sec-1")
!     .... JH1202 = 2Br
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jh1202', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jh1202', jh1202_id)
      iret = nf_put_att_text(ncid, jh1202_id, 'long_name', 25,
     $                  "CBr2F2 (H1202) + hv = 2Br" )
      iret = nf_put_att_text(ncid,jh1202_id, 'units', 5, 
     $                         "sec-1")
!================================================================================
!... Organic Iodine  based species...
!================================================================================
!     .... JCH3I = I 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jch3i', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jch3i', jch3i_id)
      iret = nf_put_att_text(ncid, jch3i_id, 'long_name', 14,
     $                  "CH3I + hv => I" )
      iret = nf_put_att_text(ncid, jch3i_id, 'units', 5, 
     $                         "sec-1")
!     .... JCH2I2 = 2I 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jch2i2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jch2i2', jch2i2_id)
      iret = nf_put_att_text(ncid, jch2i2_id, 'long_name', 15,
     $                  "CH2I2 + hv => 2I" )
      iret = nf_put_att_text(ncid, jch2i2_id, 'units', 5, 
     $                         "sec-1")
!     .... JCH2IBr = I + Br
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jch2ibr', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jch2ibr', jch2ibr_id)
      iret = nf_put_att_text(ncid, jch2ibr_id, 'long_name', 21,
     $                  "CH2IBr + hv => I + Br" )
      iret = nf_put_att_text(ncid, jch2ibr_id, 'units', 5, 
     $                         "sec-1")
!     .... JCH2ICl = I + Cl
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jch2icl', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jch2icl', jch2icl_id)
      iret = nf_put_att_text(ncid, jch2icl_id, 'long_name', 21,
     $                  "CH2ICl + hv => I + Cl" )
      iret = nf_put_att_text(ncid, jch2icl_id, 'units', 5, 
     $                         "sec-1")
!     .... JC2H5I = I 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jc2h5i', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jc2h5i', jc2h5i_id)
      iret = nf_put_att_text(ncid, jc2h5i_id, 'long_name', 15,
     $                  "C2H5I + hv => I" )
      iret = nf_put_att_text(ncid, jc2h5i_id, 'units', 5, 
     $                         "sec-1")
!     .... JCH3CHI2 = 2I
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jch3chi2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jch3chi2', jch3chi2_id)
      iret = nf_put_att_text(ncid, jch3chi2_id, 'long_name', 18,
     $                  "CH3CHI2 + hv => 2I" )
      iret = nf_put_att_text(ncid, jch3chi2_id, 'units', 5, 
     $                         "sec-1")
!     .... JC3H7I = I 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jc3h7i', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jc3h7i', jc3h7i_id)
      iret = nf_put_att_text(ncid, jc3h7i_id, 'long_name', 15,
     $                  "C3H7I + hv => I" )
      iret = nf_put_att_text(ncid, jc3h7i_id, 'units', 5, 
     $                         "sec-1")
!     .... JC4H9I = I 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jc4h9i', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jc4h9i', jc4h9i_id)
      iret = nf_put_att_text(ncid, jc4h9i_id, 'long_name', 15,
     $                  "C4H9I + hv => I" )
      iret = nf_put_att_text(ncid, jc4h9i_id, 'units', 5, 
     $                         "sec-1")

!================================================================================
! Hydrocarbon and CO2 based species...
!================================================================================
!     .... JCO2 = CO + O 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jco2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jco2', jco2_id)
      iret = nf_put_att_text(ncid, jco2_id, 'long_name', 18,
     $                  "CO2 + hv => CO + O" )
      iret = nf_put_att_text(ncid, jco2_id, 'units', 5, 
     $                         "sec-1")
!     .... JCH4 = H + CH3O2
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jch4_a', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jch4_a', jch4_a_id)
      iret = nf_put_att_text(ncid, jch4_a_id, 'long_name', 19,
     $                  "CH4 + hv => CH3 + H" )
      iret = nf_put_att_text(ncid, jch4_a_id, 'units', 5, 
     $                         "sec-1")
!     .... JCH4 = H2 + .18*CH2O...
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jch4_b', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jch4_b', jch4_b_id)
      iret = nf_put_att_text(ncid, jch4_b_id, 'long_name', 21,
     $                  "CH4 + hv => H2 + prod" )
      iret = nf_put_att_text(ncid, jch4_b_id, 'units', 5, 
     $                         "sec-1")

!     .... JCH3OOH = CH2O + H + OH
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jch3ooh', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jch3ooh', jch3ooh_id)
      iret = nf_put_att_text(ncid, jch3ooh_id, 'long_name', 28,
     $                  "CH3OOH + hv => CH2O + H + OH" )
      iret = nf_put_att_text(ncid, jch3ooh_id, 'units', 5, 
     $                         "sec-1")
!     .... JCH2O = CO + 2H
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jch2o_a', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jch2o_a', jch2o_a_id)
      iret = nf_put_att_text(ncid, jch2o_a_id, 'long_name', 20,
     $                  "CH2O + hv => CO + 2H" )
      iret = nf_put_att_text(ncid, jch2o_a_id, 'units', 5, 
     $                         "sec-1")
!     .... JCH2O = CO + H2
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jch2o_b', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jch2o_b', jch2o_b_id)
      iret = nf_put_att_text(ncid, jch2o_b_id, 'long_name', 20,
     $                  "CH2O + hv => CO + H2" )
      iret = nf_put_att_text(ncid, jch2o_b_id, 'units', 5, 
     $                         "sec-1")
!     .... JCH3CHO = CH3O2 + CO + HO2
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jch3cho', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jch3cho', jch3cho_id)
      iret = nf_put_att_text(ncid, jch3cho_id, 'long_name', 30,
     $                  "CH3CHO + hv = CH3O2 + CO + HO2" )
      iret = nf_put_att_text(ncid,jch3cho_id, 'units', 5, 
     $                         "sec-1")
!     .... JPAN = .6*CH3CO3 + .6*NO2 + .4*CH3O2 + .4*NO3
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jpan', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jpan', jpan_id)
      iret = nf_put_att_text(ncid, jpan_id, 'long_name', 15,
     $                  "PAN + hv = prod" )
      iret = nf_put_att_text(ncid,jpan_id, 'units', 5, 
     $                         "sec-1")
!     .... JMACR_a = 1.34 * HO2 + .66 * MCO3 + 1.34 * CH2O + 1.34 * CH3CO3
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jmacr_a', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jmacr_a', jmacr_a_id)
      iret = nf_put_att_text(ncid, jmacr_a_id, 'long_name', 30,
     $                  "MACR + hv = 1.34*CH3CO3 + prod" )
      iret = nf_put_att_text(ncid,jmacr_a_id, 'units', 5, 
     $                         "sec-1")
!     .... JMACR_b = CO + Prod
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jmacr_b', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jmacr_b', jmacr_b_id)
      iret = nf_put_att_text(ncid, jmacr_b_id, 'long_name', 26,
     $                  "MACR + hv = 1.34*CO + prod" )
      iret = nf_put_att_text(ncid,jmacr_b_id, 'units', 5, 
     $                         "sec-1")
!     .... JMVK 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jmvk', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jmvk', jmvk_id)
      iret = nf_put_att_text(ncid, jmvk_id, 'long_name', 15,
     $                  "MVK + hv = prod" )
      iret = nf_put_att_text(ncid,jmvk_id, 'units', 5, 
     $                         "sec-1")
!     .... JACET (CH3COCH3) = CH3CO3 + CH3O2
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jacet', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jacet', jacet_id)
      iret = nf_put_att_text(ncid, jacet_id, 'long_name', 26,
     $                  "ACET + hv = CH3CO3 + CH3O2" )
      iret = nf_put_att_text(ncid,jacet_id, 'units', 5, 
     $                         "sec-1")
!     .... JMGLY (CH3COCHO) = CH3CO3 + CO + HO2"
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jmgly', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jmgly', jmgly_id)
      iret = nf_put_att_text(ncid, jmgly_id, 'long_name', 29,
     $                  "MGLY + hv = CH3CO3 + CO + HO2" )
      iret = nf_put_att_text(ncid,jmgly_id, 'units', 5, 
     $                         "sec-1")
!     .... JHYAC (CH2(OH)COCH3 ) = CH3CO3 + CO + HO2"
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jhyac', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jhyac', jhyac_id)
      iret = nf_put_att_text(ncid, jhyac_id, 'long_name', 31,
     $                  "HYAC + hv = CH3CO3 + HO2 + CH2O" )
      iret = nf_put_att_text(ncid,jhyac_id, 'units', 5, 
     $                         "sec-1")
!     .... JGLYALD (CH2(OH)CHO) = CH2O + CO + 2HO2"
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jglyald', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jglyald', jglyald_id)
      iret = nf_put_att_text(ncid, jglyald_id, 'long_name', 30,
     $                  "GLYALD + hv = CH2O + CO + 2HO2" )
      iret = nf_put_att_text(ncid,jglyald_id, 'units', 5, 
     $                         "sec-1")
!     .... JCH3O2NO2 = prod"
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jch3o2no2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jch3o2no2', jch3o2no2_id)
      iret = nf_put_att_text(ncid, jch3o2no2_id, 'long_name', 20,
     $                  "CH3O2NO2 + hv = prod" )
      iret = nf_put_att_text(ncid,jch3o2no2_id, 'units', 5, 
     $                         "sec-1")
!================================================================================
! Sulfur based species...
!================================================================================
!     .... JSO2 = SO + O 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jso2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jso2', jso2_id)
      iret = nf_put_att_text(ncid, jso2_id, 'long_name', 18,
     $                  "SO2 + hv => SO + O" )
      iret = nf_put_att_text(ncid, jso2_id, 'units', 5, 
     $                         "sec-1")
!     .... JSO3 = SO2 + O 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jso3', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jso3', jso3_id)
      iret = nf_put_att_text(ncid, jso3_id, 'long_name', 19,
     $                  "SO3 + hv => SO2 + O" )
      iret = nf_put_att_text(ncid, jso3_id, 'units', 5, 
     $                         "sec-1")
!     .... JSO = S + O 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jso', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jso', jso_id)
      iret = nf_put_att_text(ncid, jso_id, 'long_name', 16,
     $                  "SO + hv => S + O" )
      iret = nf_put_att_text(ncid, jso_id, 'units', 5, 
     $                         "sec-1")
!     .... JH2SO3 = HSO3 + OH 
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jh2so4', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jh2so4', jh2so4_id)
      iret = nf_put_att_text(ncid, jh2so4_id, 'long_name', 23,
     $                  "H2SO4 + hv => HSO3 + OH" )
      iret = nf_put_att_text(ncid, jh2so4_id, 'units', 5, 
     $                         "sec-1")
!     .... JCS2 = CS + S
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jcs2', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jcs2', jcs2_id)
      iret = nf_put_att_text(ncid, jcs2_id, 'long_name', 18,
     $                  "CS2 + hv => CS + S" )
      iret = nf_put_att_text(ncid, jcs2_id, 'units', 5, 
     $                         "sec-1")
!     .... JOCS = CO + S
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jocs', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jocs', jocs_id)
      iret = nf_put_att_text(ncid, jocs_id, 'long_name', 18,
     $                  "OCS + hv => CO + S" )
      iret = nf_put_att_text(ncid, jocs_id, 'units', 5, 
     $                         "sec-1")
!     .... JSF6 = sink
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jsf6', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jsf6', jsf6_id)
      iret = nf_put_att_text(ncid, jsf6_id, 'long_name', 20,
     $                  "SF6 + hv => products" )
      iret = nf_put_att_text(ncid, jsf6_id, 'units', 5, 
     $                         "sec-1")

!================================================================================
!... ion photolysis ...
!================================================================================
!     .... JNO = NOp + e
	dims(1) = prsdim
      iret = ncvdef(ncid, 'jno_i', NCFLOAT, 1, dims, iret)
      iret = nf_inq_varid(ncid, 'jno_i', jno_i_id)
      iret = nf_put_att_text(ncid, jno_i_id, 'long_name', 18,
     $                  "NO + hv => NOp + e" )
      iret = nf_put_att_text(ncid, jno_i_id, 'units', 14, 
     $                         "cm2 molecule-1")

!------------------------------------------------------------------------------
!       ... Assign Global Attributes
!------------------------------------------------------------------------------
      iret = nf_put_att_text (ncid, NF_GLOBAL, 'Title', 35, 'V4.0 - Doug Kinnison, dkin@ucar.edu')

      iret = nf_put_att_text (ncid, NF_GLOBAL, 'source',24, 'Derived from STUV, JPL10')
 
!------------------------------------------------------------------------------
!       ... Leave Define Mode
!------------------------------------------------------------------------------
	call ncendf(ncid, iret)
    
!------------------------------------------------------------------------------
!       ... Load Variables
!------------------------------------------------------------------------------
        iret = nf_inq_varid   ( ncid, 'jlabels', label_id)
        count = (/ 60,1 /)
        start(1) = 1
        do ij = 1, nj

         jlabel_ex = jlabel(ij)
         print*, ij, jlabel_ex
         start(2) = ij
         iret = nf_put_vara_text( ncid, label_id, start,count,jlabel_ex)

        enddo
        
	iret = nf_inq_varid   ( ncid, 'wc', wave_id)
	iret = nf_put_var_real( ncid, wave_id, wc)
        
	iret = nf_inq_varid   ( ncid, 'wlintv', wave_id)
	iret = nf_put_var_real( ncid, wave_id, wlintv)
        
	iret = nf_inq_varid   ( ncid, 'z', z_id)
	iret = nf_put_var_real( ncid, z_id, z)
        
	iret = nf_inq_varid   ( ncid, 'pm', z_id)
	iret = nf_put_var_real( ncid, z_id, pmlev)
	
	iret = nf_inq_varid   ( ncid, 'sza', sza_id)
	iret = nf_put_var_real( ncid, sza_id, sza)
        
	iret = nf_inq_varid   ( ncid, 'alb', alb_id)
	iret = nf_put_var_real( ncid, alb_id, alb)
        
	iret = nf_inq_varid   ( ncid, 'etfphot', etfphot_id)
	iret = nf_put_var_real( ncid, etfphot_id, etfphot)
        
	iret = nf_inq_varid   ( ncid, 'norm_flux', nflx_id)
	iret = nf_put_var_real( ncid, nflx_id, norm_flux)

	iret = nf_inq_varid   ( ncid, 'jcoeff', rsf_id)
	iret = nf_put_var_real( ncid, rsf_id, jcoeff)
        
	iret = nf_inq_varid   ( ncid, 'jcoeff_wc', djdw_id)
	iret = nf_put_var_real( ncid, djdw_id, jcoeff_wc)
       
	iret = nf_inq_varid   ( ncid, 'cross_section', xs_id)
	iret = nf_put_var_real( ncid, xs_id, cross_section)

 	iret = nf_inq_varid   ( ncid, 'jo2_a', jo2_a_id)
	iret = nf_put_var_real( ncid, jo2_a_id, valj(1,:))

      	iret = nf_inq_varid   ( ncid, 'jo2_b', jo2_b_id)
	iret = nf_put_var_real( ncid, jo2_b_id, valj(2,:))

	iret = nf_inq_varid   ( ncid, 'jo3_a', jo3_a_id)
	iret = nf_put_var_real( ncid, jo3_a_id, valj(3,:))

	iret = nf_inq_varid   ( ncid, 'jo3_b', jo3_b_id)
	iret = nf_put_var_real( ncid, jo3_b_id, valj(4,:))

	iret = nf_inq_varid   ( ncid, 'jn2o', jn2o_id)
	iret = nf_put_var_real( ncid, jn2o_id,  valj(5,:))

	iret = nf_inq_varid   ( ncid, 'jno', jno_id)
	iret = nf_put_var_real( ncid, jno_id,   valj(6,:))

	iret = nf_inq_varid   ( ncid, 'jno2', jno2_id)
	iret = nf_put_var_real( ncid, jno2_id,  valj(7,:))

	iret = nf_inq_varid   ( ncid, 'jn2o5_a', jn2o5_a_id)
	iret = nf_put_var_real( ncid, jn2o5_a_id,  valj(8,:))

	iret = nf_inq_varid   ( ncid, 'jn2o5_b', jn2o5_b_id)
	iret = nf_put_var_real( ncid, jn2o5_b_id,  valj(9,:))

	iret = nf_inq_varid   ( ncid, 'jhno3', jhno3_id)
	iret = nf_put_var_real( ncid, jhno3_id,   valj(10,:))

	iret = nf_inq_varid   ( ncid, 'jno3_a', jno3_a_id)
	iret = nf_put_var_real( ncid, jno3_a_id,   valj(11,:))

	iret = nf_inq_varid   ( ncid, 'jno3_b', jno3_b_id)
	iret = nf_put_var_real( ncid, jno3_b_id,   valj(12,:))

	iret = nf_inq_varid   ( ncid, 'jho2no2_a', jho2no2_a_id)
	iret = nf_put_var_real( ncid, jho2no2_a_id,   valj(13,:))

	iret = nf_inq_varid   ( ncid, 'jho2no2_b', jho2no2_b_id)
	iret = nf_put_var_real( ncid, jho2no2_b_id,   valj(14,:))

	iret = nf_inq_varid   ( ncid, 'jch3ooh', jch3ooh_id)
	iret = nf_put_var_real( ncid, jch3ooh_id,     valj(15,:))

	iret = nf_inq_varid   ( ncid, 'jch2o_a', jch2o_a_id)
	iret = nf_put_var_real( ncid, jch2o_a_id,     valj(16,:))

	iret = nf_inq_varid   ( ncid, 'jch2o_b', jch2o_b_id)
	iret = nf_put_var_real( ncid, jch2o_b_id,     valj(17,:))

	iret = nf_inq_varid   ( ncid, 'jh2o_a', jh2o_a_id)
	iret = nf_put_var_real( ncid, jh2o_a_id,      valj(18,:))

	iret = nf_inq_varid   ( ncid, 'jh2o_b', jh2o_b_id)
	iret = nf_put_var_real( ncid, jh2o_b_id,      valj(19,:))

	iret = nf_inq_varid   ( ncid, 'jh2o_c', jh2o_c_id)
	iret = nf_put_var_real( ncid, jh2o_c_id,      valj(20,:))

	iret = nf_inq_varid   ( ncid, 'jh2o2', jh2o2_id)
	iret = nf_put_var_real( ncid, jh2o2_id,       valj(21,:))

	iret = nf_inq_varid   ( ncid, 'jcl2', jcl2_id)
	iret = nf_put_var_real( ncid, jcl2_id,        valj(22,:))

	iret = nf_inq_varid   ( ncid, 'joclo', joclo_id)
	iret = nf_put_var_real( ncid, joclo_id,       valj(23,:))

	iret = nf_inq_varid   ( ncid, 'jcl2o2', jcl2o2_id)
	iret = nf_put_var_real( ncid, jcl2o2_id,      valj(24,:))

	iret = nf_inq_varid   ( ncid, 'jhocl', jhocl_id)
	iret = nf_put_var_real( ncid, jhocl_id,       valj(25,:))

	iret = nf_inq_varid   ( ncid, 'jhcl', jhcl_id)
	iret = nf_put_var_real( ncid, jhcl_id,        valj(26,:))

	iret = nf_inq_varid   ( ncid, 'jclono2_a', jclono2_a_id)
	iret = nf_put_var_real( ncid, jclono2_a_id,   valj(27,:))

	iret = nf_inq_varid   ( ncid, 'jclono2_b', jclono2_b_id)
	iret = nf_put_var_real( ncid, jclono2_b_id,   valj(28,:))

	iret = nf_inq_varid   ( ncid, 'jbrcl', jbrcl_id)
	iret = nf_put_var_real( ncid, jbrcl_id,       valj(29,:))

	iret = nf_inq_varid   ( ncid, 'jbro', jbro_id)
	iret = nf_put_var_real( ncid, jbro_id,        valj(30,:))

	iret = nf_inq_varid   ( ncid, 'jhobr', jhobr_id)
	iret = nf_put_var_real( ncid, jhobr_id,       valj(31,:))

	iret = nf_inq_varid   ( ncid, 'jbrono2_a', jbrono2_a_id)
	iret = nf_put_var_real( ncid, jbrono2_a_id,   valj(32,:))

	iret = nf_inq_varid   ( ncid, 'jbrono2_b', jbrono2_b_id)
	iret = nf_put_var_real( ncid, jbrono2_b_id,   valj(33,:))

	iret = nf_inq_varid   ( ncid, 'jch3cl', jch3cl_id)
	iret = nf_put_var_real( ncid, jch3cl_id,      valj(34,:))

	iret = nf_inq_varid   ( ncid, 'jccl4', jccl4_id)
	iret = nf_put_var_real( ncid, jccl4_id,       valj(35,:))

	iret = nf_inq_varid   ( ncid, 'jch3ccl3', jch3ccl3_id)
	iret = nf_put_var_real( ncid, jch3ccl3_id,    valj(36,:))

	iret = nf_inq_varid   ( ncid, 'jcfcl3', jcfcl3_id)
	iret = nf_put_var_real( ncid, jcfcl3_id,      valj(37,:))

	iret = nf_inq_varid   ( ncid, 'jcf2cl2', jcf2cl2_id)
	iret = nf_put_var_real( ncid, jcf2cl2_id,     valj(38,:))

	iret = nf_inq_varid   ( ncid, 'jcfc113', jcfc113_id)
	iret = nf_put_var_real( ncid, jcfc113_id,     valj(39,:))

 	iret = nf_inq_varid   ( ncid, 'jhcfc22', jhcfc22_id)
	iret = nf_put_var_real( ncid, jhcfc22_id,     valj(40,:))

	iret = nf_inq_varid   ( ncid, 'jch3br', jch3br_id)
	iret = nf_put_var_real( ncid, jch3br_id,      valj(41,:))

	iret = nf_inq_varid   ( ncid, 'jcf3br', jcf3br_id)
	iret = nf_put_var_real( ncid, jcf3br_id,      valj(42,:))

	iret = nf_inq_varid   ( ncid, 'jcf2clbr', jcf2clbr_id)
	iret = nf_put_var_real( ncid, jcf2clbr_id,    valj(43,:))

	iret = nf_inq_varid   ( ncid, 'jco2', jco2_id)
	iret = nf_put_var_real( ncid, jco2_id,        valj(44,:))

	iret = nf_inq_varid   ( ncid, 'jch4_a', jch4_a_id)
	iret = nf_put_var_real( ncid, jch4_a_id,      valj(45,:))

	iret = nf_inq_varid   ( ncid, 'jch4_b', jch4_b_id)
	iret = nf_put_var_real( ncid, jch4_b_id,      valj(46,:))
        
	iret = nf_inq_varid   ( ncid, 'jch3cho', jch3cho_id)
	iret = nf_put_var_real( ncid, jch3cho_id,     valj(47,:))
        
	iret = nf_inq_varid   ( ncid, 'jpan', jpan_id)
	iret = nf_put_var_real( ncid, jpan_id,        valj(48,:))
 
	iret = nf_inq_varid   ( ncid, 'jmacr_a', jmacr_a_id)
	iret = nf_put_var_real( ncid, jmacr_a_id,     valj(49,:))

	iret = nf_inq_varid   ( ncid, 'jmacr_b', jmacr_b_id)
	iret = nf_put_var_real( ncid, jmacr_b_id,     valj(50,:))
        
	iret = nf_inq_varid   ( ncid, 'jmvk', jmvk_id)
	iret = nf_put_var_real( ncid, jmvk_id,        valj(51,:))
        
	iret = nf_inq_varid   ( ncid, 'jacet', jacet_id)
	iret = nf_put_var_real( ncid, jacet_id,       valj(52,:))
         
	iret = nf_inq_varid   ( ncid, 'jmgly', jmgly_id)
	iret = nf_put_var_real( ncid, jmgly_id,       valj(53,:))
         
	iret = nf_inq_varid   ( ncid, 'jhyac', jhyac_id)
	iret = nf_put_var_real( ncid, jhyac_id,       valj(54,:))
 
	iret = nf_inq_varid   ( ncid, 'jglyald', jglyald_id)
	iret = nf_put_var_real( ncid, jglyald_id,     valj(55,:))
        
	iret = nf_inq_varid   ( ncid, 'jch3o2no2', jch3o2no2_id)
	iret = nf_put_var_real( ncid, jch3o2no2_id,   valj(56,:))
        
	iret = nf_inq_varid   ( ncid, 'jhono', jhono_id)
	iret = nf_put_var_real( ncid, jhono_id,       valj(57,:))
         
	iret = nf_inq_varid   ( ncid, 'jho2', jho2_id)
	iret = nf_put_var_real( ncid, jho2_id,        valj(58,:))
 
	iret = nf_inq_varid   ( ncid, 'jh2402', jh2402_id)
	iret = nf_put_var_real( ncid, jh2402_id,      valj(59,:))
 
	iret = nf_inq_varid   ( ncid, 'jch2br2', jch2br2_id)
	iret = nf_put_var_real( ncid, jch2br2_id,     valj(60,:))
 
	iret = nf_inq_varid   ( ncid, 'jbr2', jbr2_id)
	iret = nf_put_var_real( ncid, jbr2_id,        valj(61,:))
   
	iret = nf_inq_varid   ( ncid, 'jhbr', jhbr_id)
	iret = nf_put_var_real( ncid, jhbr_id,        valj(62,:))
   
	iret = nf_inq_varid   ( ncid, 'jclo', jclo_id)
	iret = nf_put_var_real( ncid, jclo_id,        valj(63,:))
 
	iret = nf_inq_varid   ( ncid, 'jso2', jso2_id)
	iret = nf_put_var_real( ncid, jso2_id,        valj(64,:))
      
	iret = nf_inq_varid   ( ncid, 'jso3', jso3_id)
	iret = nf_put_var_real( ncid, jso3_id,        valj(65,:))
 
   	iret = nf_inq_varid   ( ncid, 'jso', jso_id)
	iret = nf_put_var_real( ncid, jso_id,         valj(66,:))
 
	iret = nf_inq_varid   ( ncid, 'jh2so4', jh2so4_id)
	iret = nf_put_var_real( ncid, jh2so4_id,      valj(67,:))
    
	iret = nf_inq_varid   ( ncid, 'jcs2', jcs2_id)
	iret = nf_put_var_real( ncid, jcs2_id,        valj(68,:))

	iret = nf_inq_varid   ( ncid, 'jocs', jocs_id)
	iret = nf_put_var_real( ncid, jocs_id,        valj(69,:))

 	iret = nf_inq_varid   ( ncid, 'jno_i', jno_i_id)
	iret = nf_put_var_real( ncid, jno_i_id,       valj(70,:))
 
 	iret = nf_inq_varid   ( ncid, 'jbrono', jbrono_id)
	iret = nf_put_var_real( ncid, jbrono_id,      valj(71,:))

 	iret = nf_inq_varid   ( ncid, 'jbrno2', jbrno2_id)
	iret = nf_put_var_real( ncid, jbrno2_id,      valj(72,:))

 	iret = nf_inq_varid   ( ncid, 'ji2', ji2_id)
	iret = nf_put_var_real( ncid, ji2_id,         valj(73,:))

 	iret = nf_inq_varid   ( ncid, 'jio', jio_id)
	iret = nf_put_var_real( ncid, jio_id,         valj(74,:))

 	iret = nf_inq_varid   ( ncid, 'joio', joio_id)
	iret = nf_put_var_real( ncid, joio_id,        valj(75,:))

 	iret = nf_inq_varid   ( ncid, 'jino', jino_id)
	iret = nf_put_var_real( ncid, jino_id,        valj(76,:))

 	iret = nf_inq_varid   ( ncid, 'jiono', jiono_id)
	iret = nf_put_var_real( ncid, jiono_id,       valj(77,:))

 	iret = nf_inq_varid   ( ncid, 'jiono2', jiono2_id)
	iret = nf_put_var_real( ncid, jiono2_id,      valj(78,:))

 	iret = nf_inq_varid   ( ncid, 'jhoi', jhoi_id)
	iret = nf_put_var_real( ncid, jhoi_id,        valj(79,:))

 	iret = nf_inq_varid   ( ncid, 'jibr', jibr_id)
	iret = nf_put_var_real( ncid, jibr_id,        valj(80,:))

 	iret = nf_inq_varid   ( ncid, 'jicl', jicl_id)
	iret = nf_put_var_real( ncid, jicl_id,        valj(81,:))

 	iret = nf_inq_varid   ( ncid, 'jchbr3', jchbr3_id)
	iret = nf_put_var_real( ncid, jchbr3_id,      valj(82,:))

 	iret = nf_inq_varid   ( ncid, 'jch2brcl', jch2brcl_id)
	iret = nf_put_var_real( ncid, jch2brcl_id,    valj(83,:))

 	iret = nf_inq_varid   ( ncid, 'jchbr2cl', jchbr2cl_id)
	iret = nf_put_var_real( ncid, jchbr2cl_id,    valj(84,:))

 	iret = nf_inq_varid   ( ncid, 'jchbrcl2', jchbrcl2_id)
	iret = nf_put_var_real( ncid, jchbrcl2_id,    valj(85,:))

 	iret = nf_inq_varid   ( ncid, 'jch3i', jch3i_id)
	iret = nf_put_var_real( ncid, jch3i_id,       valj(86,:))

 	iret = nf_inq_varid   ( ncid, 'jch2i2', jch2i2_id)
	iret = nf_put_var_real( ncid, jch2i2_id,      valj(87,:))

 	iret = nf_inq_varid   ( ncid, 'jch2ibr', jch2ibr_id)
	iret = nf_put_var_real( ncid, jch2ibr_id,     valj(88,:))

 	iret = nf_inq_varid   ( ncid, 'jch2icl', jch2icl_id)
	iret = nf_put_var_real( ncid, jch2icl_id,     valj(89,:))

 	iret = nf_inq_varid   ( ncid, 'jc2h5i', jc2h5i_id)
	iret = nf_put_var_real( ncid, jc2h5i_id,      valj(90,:))

 	iret = nf_inq_varid   ( ncid, 'jch3chi2', jch3chi2_id)
	iret = nf_put_var_real( ncid, jch3chi2_id,    valj(91,:))

 	iret = nf_inq_varid   ( ncid, 'jc3h7i', jc3h7i_id)
	iret = nf_put_var_real( ncid, jc3h7i_id,      valj(92,:))

 	iret = nf_inq_varid   ( ncid, 'jc4h9i', jc4h9i_id)
	iret = nf_put_var_real( ncid, jc4h9i_id,      valj(93,:))

 	iret = nf_inq_varid   ( ncid, 'jclno2', jclno2_id)
	iret = nf_put_var_real( ncid, jclno2_id,      valj(94,:))

 	iret = nf_inq_varid   ( ncid, 'jclono', jclono_id)
	iret = nf_put_var_real( ncid, jclono_id,      valj(95,:))

 	iret = nf_inq_varid   ( ncid, 'jhno3nat', jhno3nat_id)
	iret = nf_put_var_real( ncid, jhno3nat_id,    valj(96,:))

 	iret = nf_inq_varid   ( ncid, 'jhno3sts', jhno3sts_id)
	iret = nf_put_var_real( ncid, jhno3sts_id,    valj(97,:))

 	iret = nf_inq_varid   ( ncid, 'jcfc114', jcfc114_id)
	iret = nf_put_var_real( ncid, jcfc114_id,    valj(98,:))

 	iret = nf_inq_varid   ( ncid, 'jcfc115', jcfc115_id)
	iret = nf_put_var_real( ncid, jcfc115_id,    valj(99,:))

 	iret = nf_inq_varid   ( ncid, 'jhcfc141b', jhcfc141b_id)
	iret = nf_put_var_real( ncid, jhcfc141b_id,    valj(100,:))

 	iret = nf_inq_varid   ( ncid, 'jhcfc142b', jhcfc142b_id)
	iret = nf_put_var_real( ncid, jhcfc142b_id,    valj(101,:))

 	iret = nf_inq_varid   ( ncid, 'jh1202', jh1202_id)
	iret = nf_put_var_real( ncid, jh1202_id,    valj(102,:))

 	iret = nf_inq_varid   ( ncid, 'jcof2', jcof2_id)
	iret = nf_put_var_real( ncid, jcof2_id,    valj(103,:))

 	iret = nf_inq_varid   ( ncid, 'jcofcl', jcofcl_id)
	iret = nf_put_var_real( ncid, jcofcl_id,    valj(104,:))

 	iret = nf_inq_varid   ( ncid, 'jhf', jhf_id)
	iret = nf_put_var_real( ncid, jhf_id,       valj(105,:))

 	iret = nf_inq_varid   ( ncid, 'ji2o2', ji2o2_id)
	iret = nf_put_var_real( ncid, ji2o2_id,     valj(106,:))

 	iret = nf_inq_varid   ( ncid, 'ji2o3', ji2o3_id)
	iret = nf_put_var_real( ncid, ji2o3_id,      valj(107,:))

 	iret = nf_inq_varid   ( ncid, 'ji2o4', ji2o4_id)
	iret = nf_put_var_real( ncid, ji2o4_id,      valj(108,:))

	iret = nf_inq_varid   ( ncid, 'jsf6', jsf6_id)
	iret = nf_put_var_real( ncid, jsf6_id,       valj(109,:))

	iret = nf_inq_varid   ( ncid, 'jhi', jhi_id)
	iret = nf_put_var_real( ncid, jhi_id,        valj(110,:))

	call ncclos(ncid, iret)


90    format(f8.2,1p,4e13.5)
      end subroutine NETCDF_OUT
