      subroutine NETCDF_OUT(wc, wl,wlintv, z, pmlev, alb, sza, 
     $                      colo3_fact, colo3, rad_src_funct,etfphot)

*-----------------------------------------------------------------------------*
*=  PURPOSE:                                                                 =*
*=  Output cross section * QY for selected species that have absorptions     =*
*=  shortward of 200nm.                                                      =*
*=                                                                           =*
*=  rad_src_funct has 101 bin's, starting from 120.7 through 725nm.          =*
*=  For WACCM3 photolysis modules, bin 35 (201nm) through bin 101 (725nm)    =*
*=  will be used in mo_jlong.  ETFphot is not contained in the NetCDF file   =*
*=  (as in MZ3) - this variable is handled in another module of WACCM3       =*
*-----------------------------------------------------------------------------*
*=  PARAMETERS:                                                              =*
*                                                                            =*
*-----------------------------------------------------------------------------*
*=  EDIT HISTORY:                                                            =*
*=  01/02 created - DEK                                                      =*
*-----------------------------------------------------------------------------*

      implicit none

      include 'params'
***      include '/usr/include/netcdf.inc'
         include '/usr/local/netcdf-4.3.2/include/netcdf.inc'
!------------------------------------------------------------------------------
!       ... INPUT
!------------------------------------------------------------------------------
      integer, parameter :: numo3       = 20      ! # of column O3 factors
      integer, parameter :: numalb      = 6       ! # of albedos    
      integer, parameter :: numsza      = 24      ! # of solar zenith angles
      integer, parameter :: numz        = 151     ! # of alt levels for Z
      integer, parameter :: numwl       = 101     ! TUV wavelength grid #
      integer, parameter :: numwloffset = 34      ! >200nm grid zone #; wc(34) = 199nm

      real, intent (in)    :: wc(kw-1)		  ! Wavelengths (center grid)
      real, intent (in)    :: wlintv(kw)          ! Wavelength interval
      real, intent (in)    :: wl(kw)	          ! Wavelengths (edges)
      real, intent (in)    :: colo3_fact(numo3)   ! Column O3 factors
      real, intent (in)    :: colo3(numz)	  ! Reference Column O3, molec. cm-2
      real, intent (in)    :: z(kz)		  ! Altitude (km)
      real, intent (in)    :: alb(numalb)         ! Albedo
      real, intent (in)    :: sza(numsza)         ! Zenith angle, degrees
      real, intent (in)    :: pmlev(numz)         ! Pressure (hPa)
      real, intent (in)    :: etfphot(kw)         ! Photons cm-2 s-1 nm-1 

!     ...Radiative source functionm (radiative transfer only)
	real, intent (in) :: rad_src_funct(numalb,numo3,numsza,numz,numwl)


!------------------------------------------------------------------------------
!       ... Local variables
!------------------------------------------------------------------------------
!     wavelength length
      integer, parameter :: nw = 67		   !  is between wc @ 201 - 725nm
      integer :: iw, ialb, io3, isza, iz
     
!------------------------------------------------------------------------------
!       ... NetCDF IDs
!------------------------------------------------------------------------------
      integer :: ncid
      integer :: iret

!------------------------------------------------------------------------------
!       ... Dimension IDs
!------------------------------------------------------------------------------
      integer :: wcdim
      integer :: colo3dim
      integer :: colo3_fact_dim
      integer :: albdim
      integer :: szadim
      integer :: zdim

!------------------------------------------------------------------------------
!       ... Variable IDs
!------------------------------------------------------------------------------
      integer :: rsf_id
      integer :: wave_id
      integer :: wcid
      integer :: alb_id
      integer :: colo3_id
      integer :: colo3_fact_id
      integer :: z_id
      integer :: sza_id
      integer :: etfphot_id
      integer :: varid

!------------------------------------------------------------------------------
!       ... Variable Shapes
!------------------------------------------------------------------------------
      integer :: dims(5)

!------------------------------------------------------------------------------
!       ... Data Variables
!------------------------------------------------------------------------------
      real :: wavelength(nw)
!      real :: RSF(numalb,numo3,numsza,numz,nw)
      real :: RSF(nw, numz, numsza, numo3, numalb)
      real :: wavelength_intv(nw)
      real :: etf            (nw)				

!------------------------------------------------------------------------------
!       ... Variable adjustment
!------------------------------------------------------------------------------
!     numwloffset=34 => 199 nm; 1+numwloffset = 201nm.; 67+numwloffset = 725nm
     
      do ialb = 1, numalb
	  do io3 = 1, numo3
	    do isza = 1, numsza
	      do iz = 1, numz
	        do iw = 1, nw ! need a total of 67 wc's; iw = 1 is wc=201 nm
!                 RSF(ialb,io3,isza,iz,iw) = 
!     $                rad_src_funct(ialb, io3, isza, iz, iw+numwloffset)


                 RSF(iw,iz,isza,io3,ialb) = 
     $                rad_src_funct(ialb, io3, isza, iz, iw+numwloffset)
	        end do
            end do
	   end do
	 end do
      end do
      
      do iw = 1, nw  ! need a total of 67 wc's
	  wavelength(iw)      = wc(iw+numwloffset)
          wavelength_intv(iw) = wlintv(iw+numwloffset)
	  etf(iw)             = etfphot(iw+numwloffset)
      end do
     
!------------------------------------------------------------------------------
!       ... Enter Define Mode
!------------------------------------------------------------------------------
      iret = nf_create ('RSF_GT200nm.nc', nf_clobber, ncid)
      if (iret /= nf_noerr) then 
	  print*,"nf_create failed"
	  stop
      end if

!------------------------------------------------------------------------------
!       ... Define Dimensions
!------------------------------------------------------------------------------
      iret           = nf_def_dim(ncid, 'numwl',    nw,     wcdim)
      iret           = nf_def_dim(ncid, 'numz',     numz,   zdim)
      iret           = nf_def_dim(ncid, 'numsza',   numsza, szadim)
      iret           = nf_def_dim(ncid, 'numalb',   numalb, albdim)
      iret           = nf_def_dim(ncid, 'numcolo3fact', numo3, colo3_fact_dim)

!     wcdim          = ncddef(ncid, 'numwl',        nw,     iret)
!     zdim           = ncddef(ncid, 'numz',         numz,   iret)
!     szadim         = ncddef(ncid, 'numsza',       numsza, iret)
!     albdim         = ncddef(ncid, 'numalb',       numalb, iret)
!     colo3_fact_dim = ncddef(ncid, 'numcolo3fact', numo3,  iret)

!------------------------------------------------------------------------------
!       ... Define Variables
!------------------------------------------------------------------------------

!     .... Wavelength Grid
      dims(1) = wcdim
      iret = nf_def_var(ncid, 'wc', NF_REAL, 1, dims, wave_id)
!     iret = ncvdef(ncid, 'wc', NCFLOAT, 1, dims, iret)
!     iret = nf_inq_varid(ncid, "wc", wave_id)
      iret = nf_put_att_text(ncid, wave_id, 'long_name', 22,
     $                  "Wavelength Grid Center")
      iret = nf_put_att_text(ncid, wave_id, 'units', 2, 
     $                         "nm")

!     .... Wavelength Grid Inteval
      dims(1) = wcdim
      iret = nf_def_var(ncid, 'wlintv', NF_REAL, 1, dims, wave_id)
!     iret = ncvdef(ncid, 'wlintv', NCFLOAT, 1, dims, iret)
!     iret = nf_inq_varid(ncid, "wlintv", wave_id)
      iret = nf_put_att_text(ncid, wave_id, 'long_name', 26,
     $                  "Wavelength Grid Interval")
      iret = nf_put_att_text(ncid, wave_id, 'units', 2, 
     $                         "nm")

!     .... Z Grid
      dims(1) = zdim
      iret = nf_def_var(ncid, 'z', NF_REAL, 1, dims, z_id)
!     iret = ncvdef(ncid, 'z', NCFLOAT, 1, dims, iret)
!     iret = nf_inq_varid(ncid, "z", z_id)
      iret = nf_put_att_text(ncid, z_id, 'long_name', 8,
     $                  "Altitude")
      iret = nf_put_att_text(ncid, z_id, 'units', 2, 
     $                         "km")

!     .... Pressure Grid
      dims(1) = zdim
      iret = nf_def_var(ncid, 'pm', NF_REAL, 1, dims, z_id)
!     iret = ncvdef(ncid, 'pm', NCFLOAT, 1, dims, iret)
!     iret = nf_inq_varid(ncid, "pm", z_id)
      iret = nf_put_att_text(ncid, z_id, 'long_name', 8,
     $                  "Altitude")
      iret = nf_put_att_text(ncid, z_id, 'units', 3, 
     $                         "hPa")
!     .... SZA
      dims(1) = szadim
      iret = nf_def_var(ncid, 'sza', NF_REAL, 1, dims, sza_id)
!     iret = ncvdef(ncid, 'sza', NCFLOAT, 1, dims, iret)
!     iret = nf_inq_varid(ncid, "sza", sza_id)
	iret = nf_put_att_text(ncid, sza_id, 'long_name', 18,
     $                  "Solar Zenith Angle")
      iret = nf_put_att_text(ncid, sza_id, 'units', 7, 
     $                         "Degrees")

!     .... Albedo
      dims(1) = albdim
      iret = nf_def_var(ncid, 'alb', NF_REAL, 1, dims, alb_id)
!     iret = ncvdef(ncid, 'alb', NCFLOAT, 1, dims, iret)
!     iret = nf_inq_varid(ncid, "alb", alb_id)
	iret = nf_put_att_text(ncid, alb_id, 'long_name', 6,
     $                  "Albedo")

!     .... Column O3 Factors
      dims(1) = colo3_fact_dim
      iret = nf_def_var(ncid, 'colo3fact', NF_REAL, 1, dims,
     $                  colo3_fact_id)
!     iret = ncvdef(ncid, 'colo3fact', NCFLOAT, 1, dims, iret)
!     iret = nf_inq_varid(ncid, "colo3fact", colo3_fact_id)
	iret = nf_put_att_text(ncid, colo3_fact_id, 'long_name', 23,
     $                  "Column O3 Mult. factors")

!     .... Column O3 profile
      dims(1) = zdim
      iret = nf_def_var(ncid, 'colo3', NF_REAL, 1, dims, colo3_id)
!     iret = ncvdef(ncid, 'colo3', NCFLOAT, 1, dims, iret)
!     iret = nf_inq_varid(ncid, "colo3", colo3_id)
      iret = nf_put_att_text(ncid, colo3_id, 'long_name', 27,
     $                  "Column O3 Reference profile")
      iret = nf_put_att_text(ncid, colo3_id, 'units', 14, 
     $                         "molecules cm-2")

!     .... Extra Terrestrial Photons 
!      dims(1) = wcdim
!      iret = ncvdef(ncid, 'etfphot', NCFLOAT, 1, dims, iret)
!      iret = nf_inq_varid(ncid, "etfphot", etfphot_id)
!      iret = nf_put_att_text(ncid, etfphot_id, 'long_name', 22,
!     $                  "Extra Terrestrial Flux")
!      iret = nf_put_att_text(ncid, etfphot_id, 'units', 23, 
!     $                         "Photons cm-2 sec-1 nm-1")

!     .... rad_src_funct(ialb, io3, isza, iz, iw+34)
!      dims(5) = wcdim
!      dims(4) = zdim
!      dims(3) = szadim
!      dims(2) = colo3_fact_dim
!      dims(1) = albdim

      dims(5) = albdim
      dims(4) = colo3_fact_dim
      dims(3) = szadim
      dims(2) = zdim
      dims(1) = wcdim
      iret = nf_def_var(ncid, 'RSF', NF_REAL, 5, dims, rsf_id)
!     iret = ncvdef(ncid, 'RSF', NCFLOAT, 5, dims, iret)
!     iret = nf_inq_varid(ncid, "RSF", rsf_id)
      iret = nf_put_att_text(ncid, rsf_id, 'long_name', 28,
     $                  "Radiative Source Function")
      iret = nf_put_att_text(ncid, rsf_id, 'units', 15, 
     $                         "Normalized Flux")
     
!------------------------------------------------------------------------------
!       ... Assign Global Attributes
!------------------------------------------------------------------------------
!
!.... Coordinate variable attributes and history
!
      iret = nf_put_att_text(ncid, NF_GLOBAL, 'Title', 66, 'Normalize Actinic Flux, Version 3.0 - Doug Kinnison, dkin@ucar.edu')

      iret = nf_put_att_text(ncid, NF_GLOBAL, 'source', 45, 'Derived from TUV, 4-stream radiative transfer')
      
!------------------------------------------------------------------------------
!       ... Leave Define Mode
!------------------------------------------------------------------------------
        iret = nf_enddef( ncid )

    
!------------------------------------------------------------------------------
!       ... Load Variables
!------------------------------------------------------------------------------

	iret = nf_inq_varid   ( ncid, 'wc', wave_id)
	iret = nf_put_var_real( ncid, wave_id, wavelength)

	iret = nf_inq_varid   ( ncid, 'wlintv', wave_id)
	iret = nf_put_var_real( ncid, wave_id, wavelength_intv)

	iret = nf_inq_varid   ( ncid, 'z', z_id)
	iret = nf_put_var_real( ncid, z_id, z)

	iret = nf_inq_varid   ( ncid, 'pm', z_id)
	iret = nf_put_var_real( ncid, z_id, pmlev)
	
	iret = nf_inq_varid   ( ncid, 'sza', sza_id)
	iret = nf_put_var_real( ncid, sza_id, sza)

	iret = nf_inq_varid   ( ncid, 'alb', alb_id)
	iret = nf_put_var_real( ncid, alb_id, alb)

	iret = nf_inq_varid   ( ncid, 'colo3fact', colo3_fact_id)
	iret = nf_put_var_real( ncid, colo3_fact_id, colo3_fact)

	iret = nf_inq_varid   ( ncid, 'colo3', colo3_id)
	iret = nf_put_var_real( ncid, colo3_id, colo3)

!	iret = nf_inq_varid   ( ncid, 'etfphot', etfphot_id)
!	iret = nf_put_var_real( ncid, etfphot_id, etf)

	iret = nf_inq_varid   ( ncid, 'RSF', rsf_id)
	iret = nf_put_var_real( ncid, rsf_id, RSF)

        iret = nf_close( ncid )
!       call ncclos(ncid, iret)


90    format(f8.2,1p,4e13.5)
      end subroutine NETCDF_OUT
