      SUBROUTINE rdno2xs(nw,wl,wc,nz,no2xs,pn)
!---------------------------------------------------------------------------!
!  PURPOSE:                                                                 !
!  Read NO2 absorption cross section.  Re-grid data to match                !
!  specified wavelength working grid.                                       !
!---------------------------------------------------------------------------!
!  PARAMETERS:                                                              !
!  NW     - INTEGER, number of specified intervals + 1 in working        (I)!
!           wavelength grid                                                 !
!  WL     - REAL, vector of lower limits of wavelength intervals in      (I)!
!           working wavelength grid                                         !
!---------------------------------------------------------------------------!
!  EDIT HISTORY:                                                            !
!  02/97  Changed offset for grid-end interpolation to relative number      !
!         (x * (1 +- deltax))                                               !
!---------------------------------------------------------------------------!
      IMPLICIT NONE
      INCLUDE 'params'

      INTEGER kdata
      PARAMETER(kdata=1000)
!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
 
      integer, intent(in) :: nz
      integer, intent(in) :: nw
      character*80 pn

!-----------------------------------------------------------------------------!
!     ... input/output                                                        !
!-----------------------------------------------------------------------------!
      real, intent(out) :: no2xs(kw)

!... local:
      real x1(kdata)
      real y1(kdata),y2(kdata),y3(kdata)
      real x294(kdata), x294a(kdata), x294b(kdata), y294(kdata)
      real y294s(kdata)
      real yg294(kw)
      real yg(kw)
!      REAL a1, a2, dum
      integer ierr, i, iw, iz, n, n1, idum


!=====================================================================
!     Absorption cross sections:
!     measurements of Davidson et al. (198x) at 273K
!     from 263.8 to 648.8 nm in approximately 0.5 nm intervals
!=====================================================================
!... 294K
      open(unit=kin,
     &     file=TRIM(pn)//'XS_NO2_294K_JPL06.txt',status='old')

      read(kin,*) idum, n
      do i = 1, idum-2
        read(kin,*)
      enddo

      do i = 1, n
        read(kin,*) x294a(i), x294b(i), y294(i)
    
      enddo
      close(kin)
!---------------------------------------------------------------
!      Data need to be scaled to total area
!      per bin so that they can be used with inter3
!---------------------------------------------------------------
      do i = 1, n
         y294s(i) = (x294b(i)-x294a(i)) * y294(i)
      enddo
      close(kin)

      x294a(n+1) = x294b(n)
      n          = n+1
      n1         = n

      call inter3(nw,wl,yg294,n,x294a,y294s,0)

!     ... yg294 are per nm, so rescale by bin widths
      do iw = 1, nw-1
         if ((wc(iw) .GE. 240.9) .AND. (wc(iw) .LE. 662.5)) THEN
           yg294(iw) = yg294(iw)/(wl(iw+1)-wl(iw))
         else

           yg294(iw) = 0.0
         endif
      enddo
!-------------------------------------------------------
!     ... Check routine 
!      do iw = 1, nw-1
!        print*, iw, wc(iw), yg220(iw), yg294(iw)
!      enddo
!      stop
!-------------------------------------------------------
      do iw= 1, nw-1
         no2xs(iw) = yg294(iw)
      enddo

      end subroutine rdno2xs
