      SUBROUTINE seto2(nz,z,nw,wl,airden,dcol,o2xs1,dto2,
     $                  o2den,o2vmr,pathname)
*-----------------------------------------------------------------------------*
*=  PURPOSE:                                                                 =*
*=  Set up an altitude profile of air molecules.  Subroutine includes a      =*
*=  shape-conserving scaling method that allows scaling of the entire        =*
*=  profile to a given sea-level pressure.                                   =*
*-----------------------------------------------------------------------------*
*=  PARAMETERS:                                                              =*
*=  NZ      - INTEGER, number of specified altitude levels in the working (I)=*
*=            grid                                                           =*
*=  Z       - REAL, specified altitude working grid (km)                  (I)=*
*=  NW      - INTEGER, number of specified intervals + 1 in working       (I)=*
*=            wavelength grid                                                =*
*=  WL      - REAL, vector of lower limits of wavelength intervals in     (I)=*
*=            working wavelength grid                                        =*
*=            and each specified wavelength                                  =*
*=  DCOL    - REAL, number of air molecules per cm^2 at each specified    (O)=*
*=            altitude layer                                                 =*
*-----------------------------------------------------------------------------*
*=  EDIT HISTORY:                                                            =*
*=  02/97  Read in profile from an input file                                =*
*-----------------------------------------------------------------------------*
*= This program is free software;  you can redistribute it and/or modify     =*
*= it under the terms of the GNU General Public License as published by the  =*
*= Free Software Foundation;  either version 2 of the license, or (at your   =*
*= option) any later version.                                                =*
*= The TUV package is distributed in the hope that it will be useful, but    =*
*= WITHOUT ANY WARRANTY;  without even the implied warranty of MERCHANTIBI-  =*
*= LITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public     =*
*= License for more details.                                                 =*
*= To obtain a copy of the GNU General Public License, write to:             =*
*= Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.   =*
*-----------------------------------------------------------------------------*
*= To contact the authors, please mail to:                                   =*
*= Sasha Madronich, NCAR/ACD, P.O.Box 3000, Boulder, CO, 80307-3000, USA  or =*
*= send email to:  sasha@ucar.edu                                            =*
*-----------------------------------------------------------------------------*
*= Copyright (C) 1994,95,96  University Corporation for Atmospheric Research =*
*-----------------------------------------------------------------------------*

      implicit none
      include 'params'

!------------------------------------------------------------------------------
!     ... input: (altitude working grid)
!------------------------------------------------------------------------------
      real, intent(in)    :: z(kz)
      real, intent(in)    :: wl(kw)

      integer, intent(in) :: nw
      integer, intent(in) :: nz

      real, intent(in)    :: dcol(kz)
      real, intent(in)    :: o2xs1(kw)
      real, intent(in)    :: airden(kz)

      character*80 pathname
!------------------------------------------------------------------------------
!     ...  output:
!------------------------------------------------------------------------------
      real, intent(out) :: o2den(kz)
      real, intent(out) :: o2vmr(kz)
      real, intent(out) :: dto2(kz,kw) ! O2 abs OD per layer at each wavelength

!------------------------------------------------------------------------------
!     ... local:
!------------------------------------------------------------------------------
      real zd(kz)
      real sd(kz)
      integer iz, nd, nskip, iw

!------------------------------------------------------------------------------
!     ... read in oxygen profile
!------------------------------------------------------------------------------
      write(kout,*) 'Molecular Oxygen Profile: WACCM'

      open(kin,file=
     &  TRIM(pathname)//'waccm_O2_std_atm1.mew',status='old')
	read(kin,*) nskip, nd
      do iz = 1, nskip
        read(kin,*)
      end do

	do iz = 1, nd
        read(kin,*) zd(iz), sd(iz) 
	end do
      close(kin) 

!------------------------------------------------------------------------------
!     ... interpolate onto z-grid
!------------------------------------------------------------------------------
      nd = nd + 1 

      call inter1(nz,z,o2den,nd,zd,sd)

!      do iz= 1, nz
!      print*, iz, o2den(iz)
!      enddo
!------------------------------------------------------------------------------
!     ... Calculate volume mixing ratio
!------------------------------------------------------------------------------
      o2vmr(:) = 0
      o2vmr(1:nz-1) = o2den(1:nz-1)/airden(1:nz-1)

!------------------------------------------------------------------------------
!     ... O2 abs optical depth at each wavelength
!------------------------------------------------------------------------------
      DO iz = 1, nz-1
         do iw =1, nw - 1   
            dto2(iz,iw) = o2vmr(iz) * dcol(iz) * o2xs1(iw)
         enddo  
      enddo

!      DO iz = 50, 150
!         do iw =3, 3  
!            print*, iz, o2vmr(iz), dcol(iz), o2xs1(iw), dto2(iz,iw) 
!         enddo  
!      enddo
!      stop
     
      end subroutine SETO2
