      subroutine SETPRES(nz,z,pmlev)
!-----------------------------------------------------------------------------!
!   PURPOSE:                                                                  !
!   Set up an altitude profile of Pressure.                                   !
!-----------------------------------------------------------------------------!
!   PARAMETERS:                                                               !
!   NZ      - INTEGER, number of specified altitude levels in the working (I) !
!             grid                                                            !
!   Z       - REAL, specified altitude working grid (km)                  (I) !
!   NOLEV   - REAL, Pressure (hPa) for each altitude level(O)                 !
!-----------------------------------------------------------------------------!
!   EDIT HISTORY:                                                             !
!   01/18/02 Created Doug Kinnison
!   01/18/02 Updated Style to Fortran 90, CCSM Standands, Doug Kinnison       !
!-----------------------------------------------------------------------------!
!  This program is free software;  you can redistribute it and/or modify      !
!  it under the terms of the GNU General Public License as published by the   !
!  Free Software Foundation;  either version 2 of the license, or (at your    !
!  option) any later version.                                                 !
!  The TUV package is distributed in the hope that it will be useful, but     !
!  WITHOUT ANY WARRANTY;  without even the implied warranty of MERCHANTIBI-   !
!  LITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public      !
!  License for more details.                                                  !
!  To obtain a copy of the GNU General Public License, write to:              !
!  Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.    !
!-----------------------------------------------------------------------------!
!  To contact the authors, please mail to:                                    !
!  Sasha Madronich, NCAR/ACD, P.O.Box 3000, Boulder, CO, 80307-3000, USA  or  !
!  send email to:  sasha@ucar.edu                                             !
!-----------------------------------------------------------------------------!
!  Copyright (C) 1994,95,96  University Corporation for Atmospheric Research  !
!-----------------------------------------------------------------------------!

      implicit none
      include 'params'

!------------------------------------------------------------------------------
!     ... input: (altitude working grid)
!------------------------------------------------------------------------------
      real, intent(in)    :: z(kz)
      integer, intent(in) :: nz
!------------------------------------------------------------------------------
!     ...  output:
!------------------------------------------------------------------------------

      real, intent(out) :: pmlev(kz)

!------------------------------------------------------------------------------
!     ... local:
!------------------------------------------------------------------------------
      real zd(kz)
	real sd(kz)
      integer iz, nd, nskip

!------------------------------------------------------------------------------
!     ... read in oxygen profile
!------------------------------------------------------------------------------

      write(kout,*) 'Pressure Profile: WACCM'

      open(kin,file=
     &  'INPUT/REF_ATMS/Pm_MZ3_WA1b_45N_Noon_AnnAvg.mew',status='old')
	read(kin,*) nskip, nd
      do iz = 1, nskip
        read(kin,*)
      end do
	do iz = 1, nd
        read(kin,*) zd(iz), sd(iz) 
	end do
      close(kin) 
!------------------------------------------------------------------------------
!     ... interpolate onto z-grid
!------------------------------------------------------------------------------
      nd = nd + 1 
      call inter1(nz,z,pmlev,nd,zd,sd)

      end subroutine SETPRES
