      SUBROUTINE SETTMP(nz,z,tlev,tlay,pathname)
!-----------------------------------------------------------------------------!
!   PURPOSE:                                                                  !
!   Set up an altitude profile of temperatures.  Temperature values are       !
!   needed to compute some cross sections and quantum yields.  Distinguish    !
!   between temperature at levels and layers.                                 !
!-----------------------------------------------------------------------------!
!   PARAMETERS:                                                               !
!   NZ      - INTEGER, number of specified altitude levels in the working (I) !
!             grid                                                            !
!   Z       - REAL, specified altitude working grid (km)                  (I) !
!   TLEV    - REAL, temperature (K) at each specified altitude level      (O) !
!   TLAY    - REAL, temperature (K) at each specified altitude layer      (O) !
!-----------------------------------------------------------------------------!
!   EDIT HISTORY:                                                             !
!   02/97  Read in profile from an input file                                 !
!   01/18/02 Updated Style to Fortran 90, CCSM Standands, Doug Kinnison       !
!-----------------------------------------------------------------------------!
!  This program is free software;  you can redistribute it and/or modify      !
!  it under the terms of the GNU General Public License as published by the   !
!  Free Software Foundation;  either version 2 of the license, or (at your    !
!  option) any later version.                                                 !
!  The TUV package is distributed in the hope that it will be useful, but     !
!  WITHOUT ANY WARRANTY;  without even the implied warranty of MERCHANTIBI-   !
!  LITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public      !
!  License for more details.                                                  !
!  To obtain a copy of the GNU General Public License, write to:              !
!  Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.    !
!-----------------------------------------------------------------------------!
!  To contact the authors, please mail to:                                    !
!  Sasha Madronich, NCAR/ACD, P.O.Box 3000, Boulder, CO, 80307-3000, USA  or  !
!  send email to:  sasha@ucar.edu                                             !
!-----------------------------------------------------------------------------!
!  Copyright (C) 1994,95,96  University Corporation for Atmospheric Research  !
!-----------------------------------------------------------------------------!

      implicit none
      include 'params'

!------------------------------------------------------------------------------
!     ... input: (altitude working grid)
!------------------------------------------------------------------------------
      real, intent(in)    :: z(kz)
      integer, intent(in) :: nz
      character*80 pathname
!------------------------------------------------------------------------------
!     ...  output:
!------------------------------------------------------------------------------

      real, intent(out) :: tlev(kz)
      real, intent(out) :: tlay(kz)

!------------------------------------------------------------------------------
!     ... local:
!------------------------------------------------------------------------------
      real zd(kz)
      real td(kz)
      integer iz, nd, nskip

!------------------------------------------------------------------------------
!     ... read in temperature profile
!------------------------------------------------------------------------------

      write(kout,*) 'Air Temperature: WACCM'

      open(kin,file=
     &  TRIM(pathname)//'waccm_T_photo_comb.mew',status='old')
	read(kin,*) nskip, nd
      do iz = 1, nskip
        read(kin,*)
      end do
	do iz = 1, nd
        read(kin,*) zd(iz), td(iz) 
	end do
      close(kin) 

!------------------------------------------------------------------------------
!     ... interpolate onto z-grid
!------------------------------------------------------------------------------
      nd = nd + 1 
      call inter1(nz,z,tlev,nd,zd,td)

!------------------------------------------------------------------------------
!     ... compute layer-averages
!------------------------------------------------------------------------------

      do  iz = 1, nz - 1
         tlay(iz) = (tlev(iz+1) + tlev(iz))/2.
      end do

      end subroutine SETTMP
