      PROGRAM tuv
!_____________________________________________________________________________!
!     Tropospheric Ultraviolet-Visible (TUV) radiation model                  !
!     Version 4.2 - beta                                                      !
!     March 2002 by Madronich et al.                                          !
!     DEK Version 1.1                                                         !
!_____________________________________________________________________________!
!  This program is free software;  you can redistribute it and/or modify      !
!  it under the terms of the GNU General Public License as published by the   !
!  Free Software Foundation;  either version 2 of the license, or (at your    !
!  option) any later version.                                                 !
!  The TUV package is distributed in the hope that it will be useful, but     !
!  WITHOUT ANY WARRANTY;  without even the implied warranty of MERCHANTIBI-   !
!  LITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public      !
!  License for more details.                                                  !
!  To obtain a copy of the GNU General Public License, write to:              !
!  Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.    !
!-----------------------------------------------------------------------------!
!  To contact the authors, please mail to:                                    !
!  Sasha Madronich, NCAR/ACD, P.O.Box 3000, Boulder, CO, 80307-3000, USA  or  !
!  send email to:  sasha@ucar.edu  or tuv@acd.ucar.edu                        !
!-----------------------------------------------------------------------------!
!  Copyright (C) 1994,95,96,97,98,99,2000,01,02  University Corporation for   !
!  Atmospheric Research                                                       !
!-----------------------------------------------------------------------------!
      implicit none

!     ...include parameter file
      include 'params'

!==============================================================================
!                  SECTION 1: VARIABLES AND PARAMETERS
!==============================================================================
!     ... wavelength grid:
      integer nw, iw
      real    wl(kw), wc(kw), wu(kw), wlintv(kw)

!     ... altitude grid
      integer nz, iz
      real z(kz)

!     ... solar zenith angle and azimuth
      real zen, azim

!     ... slant pathlengths in spherical geometry
      integer nid (0:kz)
      real    dsdh(0:kz,kz)

!     ... extra terrestrial solar flux and earth-sun distance ^-2
      real etflux(kw), etf(kw)
      real esfact

!     ... ozone absorption cross section
      real o3xs(kw), s226(kw), s263(kw), s298(kw)

!     ... o2 absorption cross section
      real o2xs(kz,kw), o2xs1(kw)

!     ... so2 absorption cross section
      real so2xs(kw)

!     ... no2 absorption cross section 
      real no2xs(kw)

!     ... atmospheric optical parameters
      real tlev  (kz),   tlay(kz)
      real airden(kz),   dcol(kz), vcol(kz), scol(kz)
      real dtrl  (kz,kw)
      real dto3  (kz,kw), dto2 (kz,kw), dtso2(kz,kw), dtno2(kz,kw)
      real dtcld (kz,kw), omcld(kz,kw), gcld (kz,kw)
      real dtaer (kz,kw), omaer(kz,kw), gaer (kz,kw)
      real albedo(kw)

!     ... spectral irradiance and actinic flux (scalar irradiance)
      real edir  (kz), edn(kz), eup(kz)
      real sirrad(kz,kw)
      real fdir  (kz), fdn(kz), fup(kz)
      real saflux(kz,kw)

!     ... spectral weighting functions and weighted radiation
      integer ns, is
      real sw(ks,kw), rate(ks,kz), dose(ks)
      real drdw
      character*40 label(ks)

!     ...photolysis coefficients (j-values)
      integer nj, ij
      real sj  (kj,kz,kw), valj(kj,kz), sjint(kj,kz), sjint_tot(kj,kz)
      real djdw(kj,kz,kw)
      character*60 jlabel(kj)

!     ... new sea level pressure, surface dobson, etc.
      real pmbnew, dobnew, so2new, no2new, visnew, cldnew, albnew

!     ... Used in set gridz
      integer izout
      real z1, zout, zaird, ztemp

!     ... date for etf
      integer idate

!     ... other user-defined variables here:

      real n2den(kz)			! N2 Concentration, molecules cm-3
      real noden(kz)		        ! NO Concentration, molecules cm-3
      real o3den(kz)                    ! O3 Concentration, molecules cm-3    
      real o2den(kz)			! O2 Concentration, molecules cm-3
      real o2vmr(kz)			! O2 Volume Mixing Ratio, Derived in seto2
      real pmlev(kz)		        ! Pressure (hPa)
      real dobson			! Dobson Unit variable, returned from seto3

      real o3vcol(kz)			! O3 Vertical Column, molecules cm-2
      real o3scol(kz)			! O3 Slant Column, molecules cm-2
      real o2scol(kz)			! O2 Slant Column, molecules cm-2
      real noscol(kz)			! NO Slant Column, molecules cm-2

      real etfphot(kw)		        ! Extra Terr. Flux, units quanta cm-2 sec-1 nm-1
      real jno    (kz)			! Total JNO, units sec-1, Minsch.+Siskind, 1993
      real fnorm     (kz,kw)		! fdir(iz) + fdn(iz) + fup(iz)
      real transo2   (kz,kw)
      real transo3   (kz,kw)
      real saflux_dir(kz,kw)
      real saflux_up (kz,kw)
      real saflux_dn (kz,kw)

      real avo, GASC, PZ

      integer i,j,k
      character*60 dir
      character*80 pathname, pathname1
      dir = '../SRC/INPUT/'

!==============================================================================
!     ... SET GRIDS  
!==============================================================================

!------------------------------------------------
!     set altitudes (creates altitude grid, 
!     locates index for selected output, izout)
!------------------------------------------------
!     ... z1 = surface elevation (km)  z(1) = z1
      z1 = 0.
!      print*, "Before gridz"
      call gridz(z1,zout,izout,nz,z)
!------------------------------------------------
!     set wavelengths (creates wavelength 
!     grid: lower, center, upper of each bin)
!------------------------------------------------
      pathname = TRIM(dir)//'GRIDS/waccm2_ref_101.grid'
!      print*, "Before gridw"
      call gridw(nw,wl,wc,wu,pathname)

!==============================================================================
!     ... SPECTRAL DATA 
!==============================================================================

!------------------------------------------
!     ... Read extra terrestrial flux data:
!------------------------------------------ 
      pathname = TRIM(dir)//'SOLAR_FLUX/'
!      print*, "Before rdetfl"
      call rdetfl(nw,wl,etflux,pathname)
!-------------------------------------------
!     ... Read cross section data for 
!         o2 (will overwrite at lyman-alpha 
!         and srb wavelengths see subroutine 
!         la_srb.f)
!
!         o3 (temperature-dependent)
!         so2 
!         no2
!-------------------------------------------
      pathname = TRIM(dir)//'XSQY/'
!      print*, "Before rdo2xs"
      call rdo2xs (nw,wl,wc,o2xs1,pathname)
!      print*, "Before rdso2xs"
      call rdso2xs(nw,wl,so2xs,pathname)
!      print*, "Before rdno2xs"
      call rdno2xs(nw,wl,wc,nz,no2xs,pathname)
      
!==============================================================================
!     ... SET MODEL ATMOSPHERE 
!==============================================================================
! -----------------------------------------
!     ... set temperature profile
! -----------------------------------------
      pathname = TRIM(dir)//'REF_ATMS/'
!      print*, "Before SetTMP"
      call settmp(nz,z,tlev,tlay,pathname)

! -----------------------------------------
!     ... set air profile and Rayleigh 
!         optical depths
! -----------------------------------------
      pmbnew = -999.0
!      print*, "Before SetAIR"
      call setair(pmbnew,nz,z,nw,wl,airden,dtrl,dcol,pathname)

! -----------------------------------------
!     ... set N2 conc (molec. cm-3)
! -----------------------------------------
      n2den(:) = airden(:)*0.790

! -----------------------------------------
!     ... set NO profile (molec cm-3)
! -----------------------------------------
!      print*, "Before SetNO"
      CALL setno(nz,z,noden,pathname)

! -----------------------------------------
!     ... set Pressure profile (hPa)
!         Pm is input is consistent with
!         T and AD
! -----------------------------------------
!     CALL setpres(nz,z,pmlev,pathname)
      AVO       = 6.02214199e+23
      GASC      = 8.20580e-02
      PZ        = 1013.26
      pz = 1000.
      do iz = 1,nz
	 pmlev(iz) = PZ*airden(iz)*(tlev(iz)*Gasc*1000.)/AVO
!         print*, z(iz), airden(iz), tlev(iz), pmlev(iz)
      enddo
!      print*, PZ*1.1777e16*(259.7*Gasc*1000.)/AVO
!      print*, PZ*1.462e19*(278.8*Gasc*1000.)/AVO
!      stop
! -----------------------------------------
!     ... set O2 profile (molec. cm-3)
!         and derive dto2
! -----------------------------------------
!     ... set o2 vmr;      
!         optical depths in lyman-alpha and 
!         srb will be over-written
!         in subroutine la_srb.f
! -----------------------------------------
!     print*, "Before SetO2"
      call seto2(nz,z,nw,wl,airden,dcol,
     $           o2xs1,dto2,o2den,o2vmr,pathname)
!      print*, o2xs1
!      stop
! -----------------------------------------
!     ...set O3 reference atmosphere, 
!        ozone vertical profile and optical 
!        depths
!    ... O3xs is at 298K.
! -----------------------------------------
      dobnew    = 260.
      pathname  = TRIM(dir)//'REF_ATMS/'
      pathname1 = TRIM(dir)//'XSQY/'
!      print*, "Before SetO3"
      call seto3(dobnew,nz,z,nw,wl,
     $           tlay,o3xs,
     $           dto3,o3den,o3vcol,dobson,
     $           pathname, pathname1)
      print*, "dobson=", dobson
! -----------------------------------------
!     ... so2 vertical profile and optical 
!         depths
! -----------------------------------------
      so2new = 0.0
 !     print*, "Before SetSO2"
      call setso2(so2new,nz,z,nw,wl,so2xs,
     $            tlay,dtso2,pathname)

! -----------------------------------------
!     ... no2 vertical optical depth (also 
!         has temperature correction)
! -----------------------------------------
      no2new = 0.0
!      print*, "Before SetNO2"
      call setno2(no2new,nz,z,nw,wl,no2xs,
     $            tlay,dtno2,pathname)

! -----------------------------------------
!     ... cloud vertical profile, optical 
!         depths, single scattering albedo, 
!         asymmetry factor
! -----------------------------------------
      cldnew = 0.0
!      print*, "Before SetCLD"
      call setcld(cldnew,nz,z,nw,wl,
     $            dtcld,omcld,gcld,pathname)

! -----------------------------------------
!     ... aerosol vertical profile, optical 
!         depths, single scattering albedo, 
!         asymmetry factor
! -----------------------------------------
      visnew = -999.
!      print*, "Before SetAER"
      call setaer(visnew,nz,z,nw,wl,
     $            dtaer,omaer,gaer,pathname)

! -----------------------------------------
!     ... set albedo
! -----------------------------------------
      albnew = 0.1
!      print*, "Before SetALB"
      call setalb(albnew,nw,wl,
     $     albedo)

!==============================================================================
!     ... Photolytic Rate Constants... 
!==============================================================================
! -----------------------------------------
!     ... Dependent on T,P,AD
!     ... Not zenith angle
! -----------------------------------------
      pathname = TRIM(dir)//'XSQY/'
!      print*, "Before pchem"
      call pchem(nw,wl,nz,tlev,airden, 
     $           nj,sj,jlabel,pathname)
   
!==============================================================================
!     ... TIME AND LOCATION 
!==============================================================================
! -------------------------------------------
!     ... Specify date and compute 
!         earth-sun distance correction
!         then multiply extra-terrestrial 
!         spectral irradiance by this factor.
! -------------------------------------------
      idate = 940321
      print*, "idate =", idate
 !     print*, "Before sundis"
      call sundis(idate, esfact)
      esfact = 1.0

      print*, "ESFACT = ", esfact
      write(kout,*) 'idate = ', idate,' esfact = ', esfact

! -----------------------------------------
!     ... Convert to quanta s-1 nm-1 cm-2
!         (1.e-4 * (wc*1e-9) / 
!         (hc = 6.62E-34 * 2.998E8) )
! -----------------------------------------

      do iw = 1, nw-1
         etf(iw)     = etflux(iw) * esfact
	 etfphot(iw) = etf(iw)*5.039e11 * wc(iw)
!         print*, wc(iw), etflux(iw), etfphot(iw)
      enddo
      
! -------------------------------------------
!     ... Set solar zenith angle calculation:
! -------------------------------------------
      zen = 15.
      print*, "zen=", zen

!==============================================================================
!     ... CALCULATE ZENITH-ANGLE DEPENDENT QUANTITIES  
!==============================================================================
!     ... Slant path lengths for spherical geometry
!      print*, "Before sphers"
      call sphers(nz, z, zen, dsdh, nid)

!     ... Derive slant column for no, o3, and o2
!      print*, "Before airmas"
      call airmas(nz, z, zen, dsdh, nid, dcol, vcol, scol)
!      print*, "Before nomas"
      call nomas (nz, z, dsdh, nid, noden, noscol)
!      print*, "Before o3mas"
      call o3mas (nz, z, dsdh, nid, o3den, o3scol)
!      print*, "Before o2mas"
      call o2mas (nz, z, dsdh, nid, o2den, o2scol)

! -----------------------------------------
!     ... Recalculate effective o2 optical 
!         depth and cross sections for 
!         lyman-alpha and SRBs, must know 
!         zenith angle 
! -----------------------------------------
      pathname = TRIM(dir)//'XSQY/'
!      print*, "Before la_srb"
      call la_srb(nz,z,tlev,nw,wl,o2scol,vcol,scol,o2xs1,
     $        dto2,o2xs,pathname)

! -----------------------------------------
!     ... assign O2 cross section*QY to: 
!         sj(1,*,*) for O2 + hv => O1D
!         sj(2,*,*) for O2 + hv => O3P
! -----------------------------------------
!      print*, "Before sjo2"
         call sjo2(nz,nw,wc,o2xs,1,sj)

! -----------------------------------------
!     ... derive NO cross section 
!         (Minschwaner and Siskind, 1993)
!         sj(3,*,*) for NO + hv => N + O
! -----------------------------------------
!      print*, "Before calcjno"
      Call calcjno(nz, nw, wl, wc,
     $            o3xs, etfphot, n2den, o2scol, o3scol, noscol, jno)

!==============================================================================
!     ... Radiative Transfer   (wavelength loop)
!==============================================================================
!     ... initialize for wavelength integration
!      print*, "Before zero2"
      call zero2(valj,kj,kz)

! -----------------------------------------
!     ... main wavelength loop:
! -----------------------------------------
         sjint(:,:) = 0.0
         sjint_tot(:,:) = 0.0
!      print*, "Before rtlink"
      do iw = 1, nw-1

! -----------------------------------------
!     ... monochromatic radiative transfer:
!         outputs are  edir(iz), eup, fdir, 
!         fdn, fup
!     ... dir = direct beam, 
!         dn = down-welling diffuse, 
!         up = up-welling diffuse
! -----------------------------------------
         call rtlink(nz,z,
     $           iw, albedo(iw), zen,
     $           dsdh,nid,
     $           dtrl,
     $           dto3,
     $           dto2,
     $           dtso2,
     $           dtno2,
     $           dtcld, omcld, gcld,
     $           dtaer,omaer,gaer,
     $           edir, edn, eup, fdir, fdn, fup)

! -----------------------------------------
!     ... spectral actinic flux, 
!         quanta s-1 nm-1 cm-2, 
!         all directions:
!     ... Convert to quanta s-1 nm-1 cm-2
!         (1.e-4 * (wc*1e-9) / 
!         (hc = 6.62E-34 * 2.998E8) )
! -----------------------------------------
         do iz = 1, nz
	    fnorm (iz,iw)    = (fdir(iz) + fdn(iz) + fup(iz))
            saflux(iz,iw)    = etfphot(iw) * fnorm(iz,iw)
	    saflux_dir(iz,iw)= etfphot(iw) * fdir(iz)  
            saflux_up(iz,iw) = etfphot(iw) * fup(iz)  
	    saflux_dn(iz,iw) = etfphot(iw) * fdn(iz)  
         end do

! -----------------------------------------
!     ... Calculate Wavelength Dependent
!         photolysis rate (valj)
! -----------------------------------------

         do iz = 1, nz

             do ij = 1, nj

                djdw(ij,iz,iw) =       
     $              saflux(iz,iw) * sj(ij,iz,iw) * (wu(iw) - wl(iw))


                valj(ij,iz)    = valj(ij,iz) + djdw(ij,iz,iw)

             end do	! end species loop

         end do		! end altitude loop
         
         wlintv (iw) = wu(iw) - wl(iw)
!      write(*,99)  iw, wc(iw), fnorm (15, iw), fnorm(150,iw)
      end do		! end wavelength loop
 
! -----------------------------------------
!     .... Insert JNO rate constant into 
!          photolysis array valj(3,kz)
! -----------------------------------------
	DO iz = 1, nz
	  valj(6,iz) = jno(iz)
	END DO
 
 99     format(i4,1p, 6e13.5)

!==============================================================================
!     ... OUTPUT
!==============================================================================
!      print*, "Before NetCDF_out"
      call NetCDF_out(nz, nw, nj, wc, wl, wlintv, z, pmlev, albnew, 
     $                zen, jlabel, fnorm, sj, djdw, valj, etfphot)

	print*, "END PROGRAM TUV"
	end program TUV
