       PROGRAM tuv
!_____________________________________________________________________________!
!     Tropospheric Ultraviolet-Visible (TUV) radiation model                  !
!     Version 4.2 - beta                                                      !
!     March 2002 by Madronich et al.                                          !
!     DEK Version 1.0                                                         !
!_____________________________________________________________________________!
!  This program is free software;  you can redistribute it and/or modify      !
!  it under the terms of the GNU General Public License as published by the   !
!  Free Software Foundation;  either version 2 of the license, or (at your    !
!  option) any later version.                                                 !
!  The TUV package is distributed in the hope that it will be useful, but     !
!  WITHOUT ANY WARRANTY;  without even the implied warranty of MERCHANTIBI-   !
!  LITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public      !
!  License for more details.                                                  !
!  To obtain a copy of the GNU General Public License, write to:              !
!  Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.    !
!-----------------------------------------------------------------------------!
!  To contact the authors, please mail to:                                    !
!  Sasha Madronich, NCAR/ACD, P.O.Box 3000, Boulder, CO, 80307-3000, USA  or  !
!  send email to:  sasha@ucar.edu  or tuv@acd.ucar.edu                        !
!-----------------------------------------------------------------------------!
!  Copyright (C) 1994,95,96,97,98,99,2000,01,02  University Corporation for   !
!  Atmospheric Research                                                       !
!-----------------------------------------------------------------------------!
      implicit none

!     ...include parameter file
      include 'params'

!==============================================================================
!                  SECTION 1: VARIABLES AND PARAMETERS
!==============================================================================
!     ... wavelength grid:
      integer nw, iw
      real wl(kw), wc(kw), wu(kw)

!     ... altitude grid
      integer nz, iz
      real z(kz)

!     ... solar zenith angle and azimuth
!     ... slant pathlengths in spherical geometry
      real zen, azim
      integer nid(0:kz)
      real dsdh(0:kz,kz)

!     ... extra terrestrial solar flux and earth-sun distance ^-2
      real etflux(kw), etf(kw)
      real esfact

!     ... ozone absorption cross section
      real o3xs(kw), s226(kw), s263(kw), s298(kw)

!     ... o2 absorption cross section
      real o2xs(kz,kw), o2xs1(kw)

!     ... so2 absorption cross section
      real so2xs(kw)

!     ... no2 absorption cross section 
      real no2xs(kw)

!     ... atmospheric optical parameters
      real tlev(kz), tlay(kz)
      real airden(kz), dcol(kz), vcol(kz), scol(kz)
      real dtrl(kz,kw)
      real dto3(kz,kw), dto2(kz,kw), dtso2(kz,kw), dtno2(kz,kw)
      real dtcld(kz,kw), omcld(kz,kw), gcld(kz,kw)
      real dtaer(kz,kw), omaer(kz,kw), gaer(kz,kw)
      real albedo(kw)

!     ... spectral irradiance and actinic flux (scalar irradiance)
      real edir(kz), edn(kz), eup(kz)
      real sirrad(kz,kw)
      real fdir(kz), fdn(kz), fup(kz)
      real saflux(kz,kw)

!     ... spectral weighting functions and weighted radiation
      integer ns, is
      real sw(ks,kw), rate(ks,kz), dose(ks)
      real drdw
      character*40 label(ks)

!     ...photolysis coefficients (j-values)
      integer nj, ij
      real    sj(kj,kz,kw), cross_sec(kj,201,16,kw), pressure(16)
     &       , temperature(201)
      real djdw
      character*60 jlabel(kj)

!     ... new sea level pressure, surface dobson, etc.
      real pmbnew, dobnew, so2new, no2new, visnew, cldnew, albnew

!     ... Used in set gridz
      integer izout
      real z1, zout, zaird, ztemp

!     ... date for etf
      
      integer idate

!     ... other user-defined variables here:

      real n2den(kz)			! N2 Concentration, molecules cm-3
      real noden(kz)		        ! NO Concentration, molecules cm-3
      real o3den(kz)                    ! O3 Concentration, molecules cm-3    
      real o2den(kz)			! O2 Concentration, molecules cm-3
      
      real o2vmr(kz)			! O2 Volume Mixing Ratio, Derived in seto2
      
      real dobson			! Dobson Unit variable, returned from seto3

      real o3vcol(kz)			! O3 Vertical Column, molecules cm-2
      real o3scol(kz)			! O3 Slant Column, molecules cm-2
      real o2scol(kz)			! O2 Slant Column, molecules cm-2
      real noscol(kz)			! NO Slant Column, molecules cm-2

      real etfphot(kw)		        ! Extra Terr. Flux, units quanta cm-2 sec-1 nm-1
      real jno(kz)			! Total JNO, units sec-1, Minsch.+Siskind, 1993
      real fnorm(kz)			! fdir(iz) + fdn(iz) + fup(iz)

      real tlevin(kz)		        ! temperature (K), reference

      integer itemp
      real wlintv(kw)
      character*60 dir
      character*60 dir1
      character*80 pathname

!--------------------------
!     ... Added by jfl
!--------------------------
      integer iprs
      pressure( 1) = 1000.
      pressure( 2) =  900.
      pressure( 3) =  800.
      pressure( 4) =  700.
      pressure( 5) =  600.
      pressure( 6) =  500.
      pressure( 7) =  400.
      pressure( 8) =  300.
      pressure( 9) =  200.
      pressure(10) =  100.
      pressure(11) =   75.
      pressure(12) =   50.
      pressure(13) =   25.
      pressure(14) =   10.
      pressure(15) =    5.
      pressure(16) =    1.

      dir  = '../SRC/INPUT/'

!==============================================================================
!     ... SET GRIDS  
!==============================================================================
!------------------------------------------------
!     set altitudes (creates altitude grid, 
!     locates index for selected output, izout)
!------------------------------------------------
!     ... z1 = surface elevation (km)  z(1) = z1
      z1 = 0.
      call gridz(z1,zout,izout,nz,z)

!------------------------------------------------
!     set wavelengths (creates wavelength 
!     grid: lower, center, upper of each bin)
!------------------------------------------------
      pathname = TRIM(dir)//'GRIDS/waccm2_ref_101.grid'
      call gridw(nw,wl,wc,wu,pathname)

!==============================================================================
!     ... SPECTRAL DATA 
!==============================================================================
!-------------------------------------------
!     ... read cross section data for 
!         o2 (will overwrite at lyman-alpha 
!         and srb wavelengths see subroutine 
!         la_srb.f)
!
!         o3 (temperature-dependent)
!	  so2 
!         no2
!-------------------------------------------
      pathname = TRIM(dir)//'XSQY/'
      call rdo2xs (nw,wl,wc, o2xs1,pathname)

!==============================================================================
!     ... SET MODEL ATMOSPHERE 
!==============================================================================
! -----------------------------------------
!     ... set air profile and Rayleigh 
!         optical depths
! -----------------------------------------
      pathname = TRIM(dir)//'REF_ATMS/'
      pmbnew = -999.0
      call setair(pmbnew,nz,z,nw,wl,airden,dtrl,dcol,pathname)

! -----------------------------------------
!     ... set temperature profile
! -----------------------------------------
      call settmp(nz,z,tlev,tlay,pathname)

!==============================================================================
!     ... LUT Pressure loop
!==============================================================================
      do iprs=1,16
        pathname = TRIM(dir)//'REF_ATMS/'
        call setair(pressure(iprs),nz,z,nw,wl,airden,dtrl,dcol,pathname)
        print*, "airden=", airden(1)

!==============================================================================
!     ... LUT Temperature Loop
!==============================================================================
      do itemp = 1,201 !201
	tlevin(:) = float(itemp+149)
	print*, "temperature, pressure =", tlevin(1),pressure(iprs)

! -----------------------------------------
!     ... Dependent on T,P,AD
!     ... Not zenith angle
! -----------------------------------------
      pathname = TRIM(dir)//'XSQY/'
      call pchem(nw,wl,nz,tlevin,airden, 
     $           nj,sj,jlabel,pathname)

! -----------------------------------------
!     ... set O2 profile (molec. cm-3)
!         and derive dto2
! -----------------------------------------
!     ... set o2 vmr;      
!         optical depths in lyman-alpha and 
!         srb will be over-written
!         in subroutine la_srb.f
! -----------------------------------------
      pathname = TRIM(dir)//'REF_ATMS/'
      call seto2(nz,z,nw,wl,airden,dcol,
     $           o2xs1,dto2,o2den,o2vmr,pathname)

! -------------------------------------------
!     ... Set solar zenith angle calculation:
! -------------------------------------------
      zen = 0.0   
      print*, "zen=", zen, "pres=", pressure(iprs)

!     ... Slant path lengths for spherical geometry
      call sphers(nz, z, zen, dsdh, nid)

!     ... Derive slant column for no, o3, and o2
      call airmas(nz, z, zen, dsdh, nid, dcol, vcol, scol)
      call o2mas (nz, z, dsdh, nid, o2den, o2scol)
 
! -----------------------------------------
!     ... Recalculate effective o2 optical 
!         depth and cross sections for 
!         lyman-alpha and SRBs, must know 
!         zenith angle 
! -----------------------------------------
      pathname = TRIM(dir)//'XSQY/'
      call la_srb(nz,z,tlevin,nw,wl,o2scol,vcol,scol,o2xs1,
     $        dto2,o2xs,pathname)

! -----------------------------------------
!     ... assign O2 cross section*QY to: 
!         sj(1,*,*) for O2 + hv => O1D
!         sj(2,*,*) for O2 + hv => O3P
! -----------------------------------------
      call sjo2(nz,nw,wc,o2xs,1,sj)

! -----------------------------------------
!     ... save cross section for a given
!         temperature
!     ... For JO2->2O, we picked 20km. This
!         was a region where the total error
!         in (iw=35-37) was maximum. This 
!         changes JO2 at 20km by +0.5%
! -----------------------------------------
      cross_sec(:,itemp,iprs,:) = sj(:,1,:)
      cross_sec(2,itemp,iprs,:) = sj(2,20,:)
      temperature(itemp)        = tlevin(1)

        end do
  
      end do
! -----------------------------------------
!     ... derive wavelength interval
! -----------------------------------------
      do iw = 1, nw-1
        wlintv(iw) = wu(iw) - wl(iw)
      end do

!==============================================================================
!     ... OUTPUT
!==============================================================================
      call NetCDF_out(nj, wc, wl, wlintv, jlabel, pressure
     &               ,temperature, cross_sec)

! -----------------------------------------
!     ... FORMAT STATEMENTS
! -----------------------------------------
996   format(i4, f8.2, 1p, 5e13.5)
997   format(a8, i4, 5x, a40)
998   format(1p,a40,5e13.5)
999   format(1p,6e12.4)

      end program TUV
