       PROGRAM tuv
!_____________________________________________________________________________!
!     Tropospheric Ultraviolet-Visible (TUV) radiation model                  !
!     Version 4.2 - beta                                                      !
!     March 2002 by Madronich et al.                                          !
!     DEK Version 1.0                                                         !
!_____________________________________________________________________________!
!  This program is free software;  you can redistribute it and/or modify      !
!  it under the terms of the GNU General Public License as published by the   !
!  Free Software Foundation;  either version 2 of the license, or (at your    !
!  option) any later version.                                                 !
!  The TUV package is distributed in the hope that it will be useful, but     !
!  WITHOUT ANY WARRANTY;  without even the implied warranty of MERCHANTIBI-   !
!  LITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public      !
!  License for more details.                                                  !
!  To obtain a copy of the GNU General Public License, write to:              !
!  Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.    !
!-----------------------------------------------------------------------------!
!  To contact the authors, please mail to:                                    !
!  Sasha Madronich, NCAR/ACD, P.O.Box 3000, Boulder, CO, 80307-3000, USA  or  !
!  send email to:  sasha@ucar.edu  or tuv@acd.ucar.edu                        !
!-----------------------------------------------------------------------------!
!  Copyright (C) 1994,95,96,97,98,99,2000,01,02  University Corporation for   !
!  Atmospheric Research                                                       !
!-----------------------------------------------------------------------------!
      implicit none

!     ...include parameter file
      include 'params'

!==============================================================================
!                  SECTION 1: VARIABLES AND PARAMETERS
!==============================================================================
!     ... wavelength grid:
      integer nw, iw
      real wl(kw), wc(kw), wu(kw)

!     ... altitude grid
      integer nz, iz
      real z(kz)

!     ... solar zenith angle and azimuth
!     ... slant pathlengths in spherical geometry
      real zen, azim
      integer nid(0:kz)
      real dsdh(0:kz,kz)

!     ... extra terrestrial solar flux and earth-sun distance ^-2
      real etflux(kw), etf(kw)
      real esfact

!     ... ozone absorption cross section
      real o3xs(kw), s226(kw), s263(kw), s298(kw)

!     ... o2 absorption cross section
      real o2xs(kz,kw), o2xs1(kw)

!     ... so2 absorption cross section
      real so2xs(kw)

!     ... no2 absorption cross section 
      real no2xs(kw)

!     ... atmospheric optical parameters
      real tlev(kz), tlay(kz)
      real airden(kz), dcol(kz), vcol(kz), scol(kz)
      real dtrl(kz,kw)
      real dto3(kz,kw), dto2(kz,kw), dtso2(kz,kw), dtno2(kz,kw)
      real dtcld(kz,kw), omcld(kz,kw), gcld(kz,kw)
      real dtaer(kz,kw), omaer(kz,kw), gaer(kz,kw)
      real albedo(kw)

!     ... spectral irradiance and actinic flux (scalar irradiance)
      real edir(kz), edn(kz), eup(kz)
      real sirrad(kz,kw)
      real fdir(kz), fdn(kz), fup(kz)
      real saflux(kz,kw)

!     ... spectral weighting functions and weighted radiation
      integer ns, is
      real sw(ks,kw), rate(ks,kz), dose(ks)
      real drdw
      character*40 label(ks)

!     ...photolysis coefficients (j-values)
      integer nj, ij
      real sj(kj,kz,kw), valj(kj,kz)
      real djdw
      character*60 jlabel(kj)

!     ... new sea level pressure, surface dobson, etc.
      real pmbnew, dobnew, so2new, no2new, visnew, cldnew, albnew

!     ... Used in set gridz
      integer izout
      real z1, zout, zaird, ztemp

!     ... date for etf
      
      integer idate

!     ... other user-defined variables here:

      real n2den(kz)			! N2 Concentration, molecules cm-3
      real noden(kz)		        ! NO Concentration, molecules cm-3
      real o3den(kz)                    ! O3 Concentration, molecules cm-3    
      real o2den(kz)			! O2 Concentration, molecules cm-3
      real o2vmr(kz)			! O2 Volume Mixing Ratio, Derived in seto2
      real dobson			! Dobson Unit variable, returned from seto3
      real o3vcol(kz)			! O3 Vertical Column, molecules cm-2
      real o3scol(kz)			! O3 Slant Column, molecules cm-2
      real o2scol(kz)			! O2 Slant Column, molecules cm-2
      real noscol(kz)			! NO Slant Column, molecules cm-2
      real etfphot(kw)		        ! Extra Terr. Flux, units quanta cm-2 sec-1 nm-1
      real jno(kz)			! Total JNO, units sec-1, Minsch.+Siskind, 1993
      real fnorm(kz)			! fdir(iz) + fdn(iz) + fup(iz)

!     ... lut output
      real etfphot_ms93(5)    ! ETF in quanta s-1 nm-1 cm-2 for MS93 grid
      real o3col(kz)
      real wlintv(kw)
      real tlevin(kz)
      character*60 dir
      character*80 pathname, pathname1

      dir = '../SRC/INPUT/'
!
!==============================================================================
!     ... SET GRIDS  
!==============================================================================
!------------------------------------------------
!     set altitudes (creates altitude grid, 
!     locates index for selected output, izout)
!------------------------------------------------
!     ... z1 = surface elevation (km)  z(1) = z1
      z1 = 0.
      call gridz(z1,zout,izout,nz,z)

!------------------------------------------------
!     set wavelengths (creates wavelength 
!     grid: lower, center, upper of each bin)
!------------------------------------------------
      pathname = TRIM(dir)//'GRIDS/waccm2_ref_101.grid'
      call gridw(nw,wl,wc,wu,pathname)

!==============================================================================
!     ... SPECTRAL DATA 
!==============================================================================
!------------------------------------------
!     ... read extra terrestrial flux data:
!------------------------------------------ 
      pathname = TRIM(dir)//'SOLAR_FLUX/'
      call rdetfl(nw,wl,etflux,pathname)
     
!-------------------------------------------
!     ... read cross section data for 
!         o2 (will overwrite at lyman-alpha 
!         and srb wavelengths see subroutine 
!         la_srb.f)
!
!         o3 (temperature-dependent)
!	  so2 
!         no2
!-------------------------------------------
      pathname = TRIM(dir)//'XSQY/'
      call rdo2xs (nw, wl, wc,   o2xs1, pathname)
      call rdso2xs(nw, wl, so2xs,       pathname)
      call rdno2xs(nw, wl, wc,   nz,    no2xs,      pathname)
 
!==============================================================================
!     ... SET MODEL ATMOSPHERE 
!==============================================================================
! -----------------------------------------
!     ... set temperature profile
! -----------------------------------------
      pathname = TRIM(dir)//'REF_ATMS/'
      call settmp(nz,z,tlev,tlay,pathname)

      tlevin(:) = tlev(:)

! -----------------------------------------
!     ... set air profile and Rayleigh 
!         optical depths
! -----------------------------------------
      pmbnew = -999.0
      call setair(pmbnew,nz,z,nw,wl,airden,dtrl,dcol,pathname)

! -----------------------------------------
!     ... set N2 conc (molec. cm-3)
! -----------------------------------------
      n2den(:) = airden(:)*0.790

! -----------------------------------------
!     ... set NO profile (molec cm-3)
! -----------------------------------------
      CALL setno(nz,z,noden,pathname)

! -----------------------------------------
!     ... set O2 profile (molec. cm-3)
!         and derive dto2
! -----------------------------------------
!     ... set o2 vmr;      
!         optical depths in lyman-alpha and 
!         srb will be over-written
!         in subroutine la_srb.f
! -----------------------------------------
      call seto2(nz,z,nw,wl,airden,dcol,
     $           o2xs1,dto2,o2den,o2vmr,
     $           pathname)

! -----------------------------------------
!     ...set O3 reference atmosphere, 
!        ozone vertical profile and optical 
!        depths
! -----------------------------------------
      dobnew = 300.0
      pathname  = TRIM(dir)//'REF_ATMS/'
      pathname1 = TRIM(dir)//'XSQY/'
      call seto3(dobnew,nz,z,nw,wl,
     $           tlay,o3xs,
     $           dto3,o3den,o3vcol,dobson,
     $           pathname, pathname1)
  
! -----------------------------------------
!     ... so2 vertical profile and optical 
!         depths
! -----------------------------------------
      so2new = 0.0
      call setso2(so2new,nz,z,nw,wl,so2xs,
     $            tlay,dtso2,pathname)

! -----------------------------------------
!     ... no2 vertical optical depth (also 
!         has temperature correction)
! -----------------------------------------
      no2new = 0.0
      call setno2(no2new,nz,z,nw,wl,no2xs,
     $            tlay,dtno2,pathname)

! -----------------------------------------
!     ... cloud vertical profile, optical 
!         depths, single scattering albedo, 
!         asymmetry factor
! -----------------------------------------
      cldnew = 0.0
      call setcld(cldnew,nz,z,nw,wl,
     $            dtcld,omcld,gcld,
     $            pathname)

! -----------------------------------------
!     ... aerosol vertical profile, optical 
!         depths, single scattering albedo, 
!         asymmetry factor
! -----------------------------------------
      visnew = -999.
      call setaer(visnew,nz,z,nw,wl,
     $            dtaer,omaer,gaer,
     $            pathname)

! -----------------------------------------
!     ... set albedo
! -----------------------------------------
      albnew = 0.2 
      call setalb(albnew,nw,wl,
     $     albedo)

!==============================================================================
!     ... Photolytic Rate Constants... 
!==============================================================================
! -----------------------------------------
!     ... Dependent on T,P,AD
!     ... Not zenith angle
! -----------------------------------------
      pathname = TRIM(dir)//'XSQY/'
      call pchem(nw,wl,nz,tlev,airden, 
     $           nj,sj,jlabel,pathname)

!==============================================================================
!     ... TIME AND LOCATION 
!==============================================================================
! -------------------------------------------
!     ... Specify date and compute 
!         earth-sun distance correction
!         then multiply extra-terrestrial 
!         spectral irradiance by this factor.
! -------------------------------------------
      idate = 940321
      call sundis(idate, esfact)
      esfact = 1.0
      write(kout,*) 'idate = ', idate,' esfact = ', esfact

! -----------------------------------------
!     ... Convert to quanta s-1 nm-1 cm-2
!         (1.e-4 * (wc*1e-9) / 
!         (hc = 6.62E-34 * 2.998E8) )
! -----------------------------------------
      do iw = 1, nw-1
         etf(iw)     = etflux(iw) * esfact
	 etfphot(iw) = etf(iw)*5.039e11 * wc(iw)
      enddo

! -------------------------------------------
!     ... Set solar zenith angle calculation:
! -------------------------------------------
      zen = 0.0   
      print*, "zen=", zen

!==============================================================================
!     ... CALCULATE ZENITH-ANGLE DEPENDENT QUANTITIES  
!==============================================================================
!     ... Slant path lengths for spherical geometry
      call sphers(nz, z, zen, dsdh, nid)

!     ... Derive slant column for no, o3, and o2
      call airmas(nz, z, zen, dsdh, nid, dcol, vcol, scol)
      call nomas (nz, z, dsdh, nid, noden, noscol)
      call o3mas (nz, z, dsdh, nid, o3den, o3scol)
      call o2mas (nz, z, dsdh, nid, o2den, o2scol)
 
! -----------------------------------------
!     ... derive NO cross section 
!         (Minschwaner and Siskind, 1993)
!         sj(3,*,*) for NO + hv => N + O
! -----------------------------------------
      Call calcjno(nz, nw, wl, wc, o3xs, etfphot, 
     $       n2den, o2scol, o3scol, noscol, etfphot_ms93, jno)

!==============================================================================
!     ... Radiative Transfer   (wavelength loop)
!==============================================================================
!     ... initialize for wavelength integration
      call zero2(valj,kj,kz)

! -----------------------------------------
!     ... main wavelength loop:
! -----------------------------------------

      do iw = 1, nw-1

          wlintv(iw) = wu(iw)-wl(iw)

! -----------------------------------------
!     ... monochromatic radiative transfer:
!         outputs are  edir(iz), eup, fdir, 
!         fdn, fup
!     ... dir = direct beam, 
!         dn = down-welling diffuse, 
!         up = up-welling diffuse
! -----------------------------------------
         call rtlink(nz,z,
     $           iw, albedo(iw), zen,
     $           dsdh,nid,
     $           dtrl,
     $           dto3,
     $           dto2,
     $           dtso2,
     $           dtno2,
     $           dtcld, omcld, gcld,
     $           dtaer,omaer,gaer,
     $           edir, edn, eup, fdir, fdn, fup)

! -----------------------------------------
!     ... spectral actinic flux, 
!         quanta s-1 nm-1 cm-2, 
!         all directions:
!     ... Convert to quanta s-1 nm-1 cm-2
!         (1.e-4 * (wc*1e-9) / 
!         (hc = 6.62E-34 * 2.998E8) )
! -----------------------------------------
         do iz = 1, nz
	    fnorm (iz)    = (fdir(iz) + fdn(iz) + fup(iz))
            saflux(iz,iw) = etfphot(iw) * fnorm(iz)
         end do

! -----------------------------------------
!     ... Calculate Wavelength Dependent
!         photolysis rate (valj)
! -----------------------------------------
         do iz = 1, nz

             do ij = 1, nj

                djdw = saflux(iz,iw) * sj(ij,iz,iw)
                valj(ij,iz) = valj(ij,iz) + djdw * (wu(iw) - wl(iw))

             end do	! end species loop

         end do		! end altitude loop

      end do		! end wavelength loop


!==============================================================================
!     ... OUTPUT
!==============================================================================
       write(23,998) "100km", wc(2), wc(10), wc(20), wc(34)
       do ij = 1, nj
	   write(23,997) ij, jlabel(ij), sj(ij,100, 2), sj(ij,100,10), 
     $                     sj(ij, 100, 20), sj(ij,100,34)
       enddo

       call NETCDF_OUT(nj, wc, wl, wlintv, jlabel, sj, o2xs1)

!==============================================================================
!     ... FORMAT STATEMENTS
!==============================================================================
997   format(i3, 3x, a30, 5x, 1p, 4e11.3)
998   format(a10, 6f10.1)
999   format(1p,6e12.4)

      end program TUV
